# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .connection_option import ConnectionOption
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class OnPremiseConnector(ConnectionOption):
    """
    The details required to establish a connection to the database using an on-premises connector.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new OnPremiseConnector object with values from keyword arguments. The default value of the :py:attr:`~oci.data_safe.models.OnPremiseConnector.connection_type` attribute
        of this class is ``ONPREM_CONNECTOR`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param connection_type:
            The value to assign to the connection_type property of this OnPremiseConnector.
            Allowed values for this property are: "PRIVATE_ENDPOINT", "ONPREM_CONNECTOR"
        :type connection_type: str

        :param on_prem_connector_id:
            The value to assign to the on_prem_connector_id property of this OnPremiseConnector.
        :type on_prem_connector_id: str

        """
        self.swagger_types = {
            'connection_type': 'str',
            'on_prem_connector_id': 'str'
        }

        self.attribute_map = {
            'connection_type': 'connectionType',
            'on_prem_connector_id': 'onPremConnectorId'
        }

        self._connection_type = None
        self._on_prem_connector_id = None
        self._connection_type = 'ONPREM_CONNECTOR'

    @property
    def on_prem_connector_id(self):
        """
        Gets the on_prem_connector_id of this OnPremiseConnector.
        The OCID of the on-premises connector.


        :return: The on_prem_connector_id of this OnPremiseConnector.
        :rtype: str
        """
        return self._on_prem_connector_id

    @on_prem_connector_id.setter
    def on_prem_connector_id(self, on_prem_connector_id):
        """
        Sets the on_prem_connector_id of this OnPremiseConnector.
        The OCID of the on-premises connector.


        :param on_prem_connector_id: The on_prem_connector_id of this OnPremiseConnector.
        :type: str
        """
        self._on_prem_connector_id = on_prem_connector_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class BdsInstance(object):
    """
    Description of the cluster.
    """

    #: A constant which can be used with the lifecycle_state property of a BdsInstance.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a BdsInstance.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a BdsInstance.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a BdsInstance.
    #: This constant has a value of "SUSPENDING"
    LIFECYCLE_STATE_SUSPENDING = "SUSPENDING"

    #: A constant which can be used with the lifecycle_state property of a BdsInstance.
    #: This constant has a value of "SUSPENDED"
    LIFECYCLE_STATE_SUSPENDED = "SUSPENDED"

    #: A constant which can be used with the lifecycle_state property of a BdsInstance.
    #: This constant has a value of "RESUMING"
    LIFECYCLE_STATE_RESUMING = "RESUMING"

    #: A constant which can be used with the lifecycle_state property of a BdsInstance.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a BdsInstance.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a BdsInstance.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the cluster_version property of a BdsInstance.
    #: This constant has a value of "CDH5"
    CLUSTER_VERSION_CDH5 = "CDH5"

    #: A constant which can be used with the cluster_version property of a BdsInstance.
    #: This constant has a value of "CDH6"
    CLUSTER_VERSION_CDH6 = "CDH6"

    #: A constant which can be used with the cluster_version property of a BdsInstance.
    #: This constant has a value of "ODH1"
    CLUSTER_VERSION_ODH1 = "ODH1"

    def __init__(self, **kwargs):
        """
        Initializes a new BdsInstance object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this BdsInstance.
        :type id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this BdsInstance.
        :type compartment_id: str

        :param display_name:
            The value to assign to the display_name property of this BdsInstance.
        :type display_name: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this BdsInstance.
            Allowed values for this property are: "CREATING", "ACTIVE", "UPDATING", "SUSPENDING", "SUSPENDED", "RESUMING", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param cluster_version:
            The value to assign to the cluster_version property of this BdsInstance.
            Allowed values for this property are: "CDH5", "CDH6", "ODH1", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type cluster_version: str

        :param is_high_availability:
            The value to assign to the is_high_availability property of this BdsInstance.
        :type is_high_availability: bool

        :param is_secure:
            The value to assign to the is_secure property of this BdsInstance.
        :type is_secure: bool

        :param is_cloud_sql_configured:
            The value to assign to the is_cloud_sql_configured property of this BdsInstance.
        :type is_cloud_sql_configured: bool

        :param network_config:
            The value to assign to the network_config property of this BdsInstance.
        :type network_config: oci.bds.models.NetworkConfig

        :param cluster_details:
            The value to assign to the cluster_details property of this BdsInstance.
        :type cluster_details: oci.bds.models.ClusterDetails

        :param nodes:
            The value to assign to the nodes property of this BdsInstance.
        :type nodes: list[oci.bds.models.Node]

        :param cloud_sql_details:
            The value to assign to the cloud_sql_details property of this BdsInstance.
        :type cloud_sql_details: oci.bds.models.CloudSqlDetails

        :param created_by:
            The value to assign to the created_by property of this BdsInstance.
        :type created_by: str

        :param time_created:
            The value to assign to the time_created property of this BdsInstance.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this BdsInstance.
        :type time_updated: datetime

        :param number_of_nodes:
            The value to assign to the number_of_nodes property of this BdsInstance.
        :type number_of_nodes: int

        :param freeform_tags:
            The value to assign to the freeform_tags property of this BdsInstance.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this BdsInstance.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'compartment_id': 'str',
            'display_name': 'str',
            'lifecycle_state': 'str',
            'cluster_version': 'str',
            'is_high_availability': 'bool',
            'is_secure': 'bool',
            'is_cloud_sql_configured': 'bool',
            'network_config': 'NetworkConfig',
            'cluster_details': 'ClusterDetails',
            'nodes': 'list[Node]',
            'cloud_sql_details': 'CloudSqlDetails',
            'created_by': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'number_of_nodes': 'int',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'compartment_id': 'compartmentId',
            'display_name': 'displayName',
            'lifecycle_state': 'lifecycleState',
            'cluster_version': 'clusterVersion',
            'is_high_availability': 'isHighAvailability',
            'is_secure': 'isSecure',
            'is_cloud_sql_configured': 'isCloudSqlConfigured',
            'network_config': 'networkConfig',
            'cluster_details': 'clusterDetails',
            'nodes': 'nodes',
            'cloud_sql_details': 'cloudSqlDetails',
            'created_by': 'createdBy',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'number_of_nodes': 'numberOfNodes',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._id = None
        self._compartment_id = None
        self._display_name = None
        self._lifecycle_state = None
        self._cluster_version = None
        self._is_high_availability = None
        self._is_secure = None
        self._is_cloud_sql_configured = None
        self._network_config = None
        self._cluster_details = None
        self._nodes = None
        self._cloud_sql_details = None
        self._created_by = None
        self._time_created = None
        self._time_updated = None
        self._number_of_nodes = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this BdsInstance.
        The OCID of the Big Data Service resource.


        :return: The id of this BdsInstance.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this BdsInstance.
        The OCID of the Big Data Service resource.


        :param id: The id of this BdsInstance.
        :type: str
        """
        self._id = id

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this BdsInstance.
        The OCID of the compartment.


        :return: The compartment_id of this BdsInstance.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this BdsInstance.
        The OCID of the compartment.


        :param compartment_id: The compartment_id of this BdsInstance.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this BdsInstance.
        The name of the cluster.


        :return: The display_name of this BdsInstance.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this BdsInstance.
        The name of the cluster.


        :param display_name: The display_name of this BdsInstance.
        :type: str
        """
        self._display_name = display_name

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this BdsInstance.
        The state of the cluster.

        Allowed values for this property are: "CREATING", "ACTIVE", "UPDATING", "SUSPENDING", "SUSPENDED", "RESUMING", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this BdsInstance.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this BdsInstance.
        The state of the cluster.


        :param lifecycle_state: The lifecycle_state of this BdsInstance.
        :type: str
        """
        allowed_values = ["CREATING", "ACTIVE", "UPDATING", "SUSPENDING", "SUSPENDED", "RESUMING", "DELETING", "DELETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def cluster_version(self):
        """
        Gets the cluster_version of this BdsInstance.
        Version of the Hadoop distribution.

        Allowed values for this property are: "CDH5", "CDH6", "ODH1", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The cluster_version of this BdsInstance.
        :rtype: str
        """
        return self._cluster_version

    @cluster_version.setter
    def cluster_version(self, cluster_version):
        """
        Sets the cluster_version of this BdsInstance.
        Version of the Hadoop distribution.


        :param cluster_version: The cluster_version of this BdsInstance.
        :type: str
        """
        allowed_values = ["CDH5", "CDH6", "ODH1"]
        if not value_allowed_none_or_none_sentinel(cluster_version, allowed_values):
            cluster_version = 'UNKNOWN_ENUM_VALUE'
        self._cluster_version = cluster_version

    @property
    def is_high_availability(self):
        """
        **[Required]** Gets the is_high_availability of this BdsInstance.
        Boolean flag specifying whether or not the cluster is highly available (HA)


        :return: The is_high_availability of this BdsInstance.
        :rtype: bool
        """
        return self._is_high_availability

    @is_high_availability.setter
    def is_high_availability(self, is_high_availability):
        """
        Sets the is_high_availability of this BdsInstance.
        Boolean flag specifying whether or not the cluster is highly available (HA)


        :param is_high_availability: The is_high_availability of this BdsInstance.
        :type: bool
        """
        self._is_high_availability = is_high_availability

    @property
    def is_secure(self):
        """
        **[Required]** Gets the is_secure of this BdsInstance.
        Boolean flag specifying whether or not the cluster should be set up as secure.


        :return: The is_secure of this BdsInstance.
        :rtype: bool
        """
        return self._is_secure

    @is_secure.setter
    def is_secure(self, is_secure):
        """
        Sets the is_secure of this BdsInstance.
        Boolean flag specifying whether or not the cluster should be set up as secure.


        :param is_secure: The is_secure of this BdsInstance.
        :type: bool
        """
        self._is_secure = is_secure

    @property
    def is_cloud_sql_configured(self):
        """
        **[Required]** Gets the is_cloud_sql_configured of this BdsInstance.
        Boolean flag specifying whether or not Cloud SQL should be configured.


        :return: The is_cloud_sql_configured of this BdsInstance.
        :rtype: bool
        """
        return self._is_cloud_sql_configured

    @is_cloud_sql_configured.setter
    def is_cloud_sql_configured(self, is_cloud_sql_configured):
        """
        Sets the is_cloud_sql_configured of this BdsInstance.
        Boolean flag specifying whether or not Cloud SQL should be configured.


        :param is_cloud_sql_configured: The is_cloud_sql_configured of this BdsInstance.
        :type: bool
        """
        self._is_cloud_sql_configured = is_cloud_sql_configured

    @property
    def network_config(self):
        """
        Gets the network_config of this BdsInstance.

        :return: The network_config of this BdsInstance.
        :rtype: oci.bds.models.NetworkConfig
        """
        return self._network_config

    @network_config.setter
    def network_config(self, network_config):
        """
        Sets the network_config of this BdsInstance.

        :param network_config: The network_config of this BdsInstance.
        :type: oci.bds.models.NetworkConfig
        """
        self._network_config = network_config

    @property
    def cluster_details(self):
        """
        Gets the cluster_details of this BdsInstance.

        :return: The cluster_details of this BdsInstance.
        :rtype: oci.bds.models.ClusterDetails
        """
        return self._cluster_details

    @cluster_details.setter
    def cluster_details(self, cluster_details):
        """
        Sets the cluster_details of this BdsInstance.

        :param cluster_details: The cluster_details of this BdsInstance.
        :type: oci.bds.models.ClusterDetails
        """
        self._cluster_details = cluster_details

    @property
    def nodes(self):
        """
        **[Required]** Gets the nodes of this BdsInstance.
        The list of nodes in the cluster.


        :return: The nodes of this BdsInstance.
        :rtype: list[oci.bds.models.Node]
        """
        return self._nodes

    @nodes.setter
    def nodes(self, nodes):
        """
        Sets the nodes of this BdsInstance.
        The list of nodes in the cluster.


        :param nodes: The nodes of this BdsInstance.
        :type: list[oci.bds.models.Node]
        """
        self._nodes = nodes

    @property
    def cloud_sql_details(self):
        """
        Gets the cloud_sql_details of this BdsInstance.

        :return: The cloud_sql_details of this BdsInstance.
        :rtype: oci.bds.models.CloudSqlDetails
        """
        return self._cloud_sql_details

    @cloud_sql_details.setter
    def cloud_sql_details(self, cloud_sql_details):
        """
        Sets the cloud_sql_details of this BdsInstance.

        :param cloud_sql_details: The cloud_sql_details of this BdsInstance.
        :type: oci.bds.models.CloudSqlDetails
        """
        self._cloud_sql_details = cloud_sql_details

    @property
    def created_by(self):
        """
        Gets the created_by of this BdsInstance.
        The user who created the cluster.


        :return: The created_by of this BdsInstance.
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """
        Sets the created_by of this BdsInstance.
        The user who created the cluster.


        :param created_by: The created_by of this BdsInstance.
        :type: str
        """
        self._created_by = created_by

    @property
    def time_created(self):
        """
        Gets the time_created of this BdsInstance.
        The time the cluster was created, shown as an RFC 3339 formatted datetime string.


        :return: The time_created of this BdsInstance.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this BdsInstance.
        The time the cluster was created, shown as an RFC 3339 formatted datetime string.


        :param time_created: The time_created of this BdsInstance.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        Gets the time_updated of this BdsInstance.
        The time the cluster was updated, shown as an RFC 3339 formatted datetime string.


        :return: The time_updated of this BdsInstance.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this BdsInstance.
        The time the cluster was updated, shown as an RFC 3339 formatted datetime string.


        :param time_updated: The time_updated of this BdsInstance.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def number_of_nodes(self):
        """
        **[Required]** Gets the number_of_nodes of this BdsInstance.
        Number of nodes that forming the cluster


        :return: The number_of_nodes of this BdsInstance.
        :rtype: int
        """
        return self._number_of_nodes

    @number_of_nodes.setter
    def number_of_nodes(self, number_of_nodes):
        """
        Sets the number_of_nodes of this BdsInstance.
        Number of nodes that forming the cluster


        :param number_of_nodes: The number_of_nodes of this BdsInstance.
        :type: int
        """
        self._number_of_nodes = number_of_nodes

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this BdsInstance.
        Simple key-value pair that is applied without any predefined name, type, or scope.
        Exists for cross-compatibility only. For example, `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this BdsInstance.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this BdsInstance.
        Simple key-value pair that is applied without any predefined name, type, or scope.
        Exists for cross-compatibility only. For example, `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this BdsInstance.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this BdsInstance.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For example, `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this BdsInstance.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this BdsInstance.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For example, `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this BdsInstance.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ResolverRule(object):
    """
    A rule for a resolver. Specifying both qnameCoverConditions and clientAddressConditions is not allowed.

    **Warning:** Oracle recommends that you avoid using any confidential information when you supply string values using the API.
    """

    #: A constant which can be used with the action property of a ResolverRule.
    #: This constant has a value of "FORWARD"
    ACTION_FORWARD = "FORWARD"

    def __init__(self, **kwargs):
        """
        Initializes a new ResolverRule object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.dns.models.ResolverForwardRule`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param client_address_conditions:
            The value to assign to the client_address_conditions property of this ResolverRule.
        :type client_address_conditions: list[str]

        :param qname_cover_conditions:
            The value to assign to the qname_cover_conditions property of this ResolverRule.
        :type qname_cover_conditions: list[str]

        :param action:
            The value to assign to the action property of this ResolverRule.
            Allowed values for this property are: "FORWARD", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type action: str

        """
        self.swagger_types = {
            'client_address_conditions': 'list[str]',
            'qname_cover_conditions': 'list[str]',
            'action': 'str'
        }

        self.attribute_map = {
            'client_address_conditions': 'clientAddressConditions',
            'qname_cover_conditions': 'qnameCoverConditions',
            'action': 'action'
        }

        self._client_address_conditions = None
        self._qname_cover_conditions = None
        self._action = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['action']

        if type == 'FORWARD':
            return 'ResolverForwardRule'
        else:
            return 'ResolverRule'

    @property
    def client_address_conditions(self):
        """
        **[Required]** Gets the client_address_conditions of this ResolverRule.
        A list of CIDR blocks. The query must come from a client within one of the blocks in order for the rule action
        to apply.


        :return: The client_address_conditions of this ResolverRule.
        :rtype: list[str]
        """
        return self._client_address_conditions

    @client_address_conditions.setter
    def client_address_conditions(self, client_address_conditions):
        """
        Sets the client_address_conditions of this ResolverRule.
        A list of CIDR blocks. The query must come from a client within one of the blocks in order for the rule action
        to apply.


        :param client_address_conditions: The client_address_conditions of this ResolverRule.
        :type: list[str]
        """
        self._client_address_conditions = client_address_conditions

    @property
    def qname_cover_conditions(self):
        """
        **[Required]** Gets the qname_cover_conditions of this ResolverRule.
        A list of domain names. The query must be covered by one of the domains in order for the rule action to apply.


        :return: The qname_cover_conditions of this ResolverRule.
        :rtype: list[str]
        """
        return self._qname_cover_conditions

    @qname_cover_conditions.setter
    def qname_cover_conditions(self, qname_cover_conditions):
        """
        Sets the qname_cover_conditions of this ResolverRule.
        A list of domain names. The query must be covered by one of the domains in order for the rule action to apply.


        :param qname_cover_conditions: The qname_cover_conditions of this ResolverRule.
        :type: list[str]
        """
        self._qname_cover_conditions = qname_cover_conditions

    @property
    def action(self):
        """
        **[Required]** Gets the action of this ResolverRule.
        The action determines the behavior of the rule. If a query matches a supplied condition, the action will
        apply. If there are no conditions on the rule, all queries are subject to the specified action.
        * `FORWARD` - Matching requests will be forwarded from the source interface to the destination address.

        Allowed values for this property are: "FORWARD", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The action of this ResolverRule.
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """
        Sets the action of this ResolverRule.
        The action determines the behavior of the rule. If a query matches a supplied condition, the action will
        apply. If there are no conditions on the rule, all queries are subject to the specified action.
        * `FORWARD` - Matching requests will be forwarded from the source interface to the destination address.


        :param action: The action of this ResolverRule.
        :type: str
        """
        allowed_values = ["FORWARD"]
        if not value_allowed_none_or_none_sentinel(action, allowed_values):
            action = 'UNKNOWN_ENUM_VALUE'
        self._action = action

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class FacetedSearchAggregation(object):
    """
    Aggregation/facets on properties of data object.
    """

    #: A constant which can be used with the property_type property of a FacetedSearchAggregation.
    #: This constant has a value of "CUSTOM_PROPERTY"
    PROPERTY_TYPE_CUSTOM_PROPERTY = "CUSTOM_PROPERTY"

    #: A constant which can be used with the property_type property of a FacetedSearchAggregation.
    #: This constant has a value of "DEFAULT_PROPERTY"
    PROPERTY_TYPE_DEFAULT_PROPERTY = "DEFAULT_PROPERTY"

    def __init__(self, **kwargs):
        """
        Initializes a new FacetedSearchAggregation object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this FacetedSearchAggregation.
        :type type: str

        :param aggregation:
            The value to assign to the aggregation property of this FacetedSearchAggregation.
        :type aggregation: dict(str, int)

        :param data_type:
            The value to assign to the data_type property of this FacetedSearchAggregation.
        :type data_type: str

        :param property_type:
            The value to assign to the property_type property of this FacetedSearchAggregation.
            Allowed values for this property are: "CUSTOM_PROPERTY", "DEFAULT_PROPERTY", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type property_type: str

        """
        self.swagger_types = {
            'type': 'str',
            'aggregation': 'dict(str, int)',
            'data_type': 'str',
            'property_type': 'str'
        }

        self.attribute_map = {
            'type': 'type',
            'aggregation': 'aggregation',
            'data_type': 'dataType',
            'property_type': 'propertyType'
        }

        self._type = None
        self._aggregation = None
        self._data_type = None
        self._property_type = None

    @property
    def type(self):
        """
        Gets the type of this FacetedSearchAggregation.
        Name of data object property


        :return: The type of this FacetedSearchAggregation.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this FacetedSearchAggregation.
        Name of data object property


        :param type: The type of this FacetedSearchAggregation.
        :type: str
        """
        self._type = type

    @property
    def aggregation(self):
        """
        Gets the aggregation of this FacetedSearchAggregation.
        Count of number of data objects having property.


        :return: The aggregation of this FacetedSearchAggregation.
        :rtype: dict(str, int)
        """
        return self._aggregation

    @aggregation.setter
    def aggregation(self, aggregation):
        """
        Sets the aggregation of this FacetedSearchAggregation.
        Count of number of data objects having property.


        :param aggregation: The aggregation of this FacetedSearchAggregation.
        :type: dict(str, int)
        """
        self._aggregation = aggregation

    @property
    def data_type(self):
        """
        Gets the data_type of this FacetedSearchAggregation.
        Data type of object property.


        :return: The data_type of this FacetedSearchAggregation.
        :rtype: str
        """
        return self._data_type

    @data_type.setter
    def data_type(self, data_type):
        """
        Sets the data_type of this FacetedSearchAggregation.
        Data type of object property.


        :param data_type: The data_type of this FacetedSearchAggregation.
        :type: str
        """
        self._data_type = data_type

    @property
    def property_type(self):
        """
        Gets the property_type of this FacetedSearchAggregation.
        Type of property that indicates if it was defined by the user or system.
        CUSTOM_PROPERTY is defined by the user on a data object.
        DEFAULT_PROPERTY is defined by the system on a data object.

        Allowed values for this property are: "CUSTOM_PROPERTY", "DEFAULT_PROPERTY", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The property_type of this FacetedSearchAggregation.
        :rtype: str
        """
        return self._property_type

    @property_type.setter
    def property_type(self, property_type):
        """
        Sets the property_type of this FacetedSearchAggregation.
        Type of property that indicates if it was defined by the user or system.
        CUSTOM_PROPERTY is defined by the user on a data object.
        DEFAULT_PROPERTY is defined by the system on a data object.


        :param property_type: The property_type of this FacetedSearchAggregation.
        :type: str
        """
        allowed_values = ["CUSTOM_PROPERTY", "DEFAULT_PROPERTY"]
        if not value_allowed_none_or_none_sentinel(property_type, allowed_values):
            property_type = 'UNKNOWN_ENUM_VALUE'
        self._property_type = property_type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateDrgAttachmentDetails(object):
    """
    UpdateDrgAttachmentDetails model.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateDrgAttachmentDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this UpdateDrgAttachmentDetails.
        :type display_name: str

        :param drg_route_table_id:
            The value to assign to the drg_route_table_id property of this UpdateDrgAttachmentDetails.
        :type drg_route_table_id: str

        :param network_details:
            The value to assign to the network_details property of this UpdateDrgAttachmentDetails.
        :type network_details: oci.core.models.DrgAttachmentNetworkUpdateDetails

        :param defined_tags:
            The value to assign to the defined_tags property of this UpdateDrgAttachmentDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param freeform_tags:
            The value to assign to the freeform_tags property of this UpdateDrgAttachmentDetails.
        :type freeform_tags: dict(str, str)

        :param export_drg_route_distribution_id:
            The value to assign to the export_drg_route_distribution_id property of this UpdateDrgAttachmentDetails.
        :type export_drg_route_distribution_id: str

        :param route_table_id:
            The value to assign to the route_table_id property of this UpdateDrgAttachmentDetails.
        :type route_table_id: str

        """
        self.swagger_types = {
            'display_name': 'str',
            'drg_route_table_id': 'str',
            'network_details': 'DrgAttachmentNetworkUpdateDetails',
            'defined_tags': 'dict(str, dict(str, object))',
            'freeform_tags': 'dict(str, str)',
            'export_drg_route_distribution_id': 'str',
            'route_table_id': 'str'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'drg_route_table_id': 'drgRouteTableId',
            'network_details': 'networkDetails',
            'defined_tags': 'definedTags',
            'freeform_tags': 'freeformTags',
            'export_drg_route_distribution_id': 'exportDrgRouteDistributionId',
            'route_table_id': 'routeTableId'
        }

        self._display_name = None
        self._drg_route_table_id = None
        self._network_details = None
        self._defined_tags = None
        self._freeform_tags = None
        self._export_drg_route_distribution_id = None
        self._route_table_id = None

    @property
    def display_name(self):
        """
        Gets the display_name of this UpdateDrgAttachmentDetails.
        A user-friendly name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :return: The display_name of this UpdateDrgAttachmentDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this UpdateDrgAttachmentDetails.
        A user-friendly name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :param display_name: The display_name of this UpdateDrgAttachmentDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def drg_route_table_id(self):
        """
        Gets the drg_route_table_id of this UpdateDrgAttachmentDetails.
        The `OCID`__ of the DRG route table that is assigned to this attachment.

        The DRG route table manages traffic inside the DRG.

        You can't remove a DRG route table from a DRG attachment, but you can reassign which
        DRG route table it uses.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The drg_route_table_id of this UpdateDrgAttachmentDetails.
        :rtype: str
        """
        return self._drg_route_table_id

    @drg_route_table_id.setter
    def drg_route_table_id(self, drg_route_table_id):
        """
        Sets the drg_route_table_id of this UpdateDrgAttachmentDetails.
        The `OCID`__ of the DRG route table that is assigned to this attachment.

        The DRG route table manages traffic inside the DRG.

        You can't remove a DRG route table from a DRG attachment, but you can reassign which
        DRG route table it uses.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param drg_route_table_id: The drg_route_table_id of this UpdateDrgAttachmentDetails.
        :type: str
        """
        self._drg_route_table_id = drg_route_table_id

    @property
    def network_details(self):
        """
        Gets the network_details of this UpdateDrgAttachmentDetails.

        :return: The network_details of this UpdateDrgAttachmentDetails.
        :rtype: oci.core.models.DrgAttachmentNetworkUpdateDetails
        """
        return self._network_details

    @network_details.setter
    def network_details(self, network_details):
        """
        Sets the network_details of this UpdateDrgAttachmentDetails.

        :param network_details: The network_details of this UpdateDrgAttachmentDetails.
        :type: oci.core.models.DrgAttachmentNetworkUpdateDetails
        """
        self._network_details = network_details

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this UpdateDrgAttachmentDetails.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this UpdateDrgAttachmentDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this UpdateDrgAttachmentDetails.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this UpdateDrgAttachmentDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this UpdateDrgAttachmentDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this UpdateDrgAttachmentDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this UpdateDrgAttachmentDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this UpdateDrgAttachmentDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def export_drg_route_distribution_id(self):
        """
        Gets the export_drg_route_distribution_id of this UpdateDrgAttachmentDetails.
        The `OCID`__ of the export route distribution used to specify how routes in the assigned DRG route table
        are advertised out through the attachment.
        If this value is null, no routes are advertised through this attachment.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The export_drg_route_distribution_id of this UpdateDrgAttachmentDetails.
        :rtype: str
        """
        return self._export_drg_route_distribution_id

    @export_drg_route_distribution_id.setter
    def export_drg_route_distribution_id(self, export_drg_route_distribution_id):
        """
        Sets the export_drg_route_distribution_id of this UpdateDrgAttachmentDetails.
        The `OCID`__ of the export route distribution used to specify how routes in the assigned DRG route table
        are advertised out through the attachment.
        If this value is null, no routes are advertised through this attachment.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param export_drg_route_distribution_id: The export_drg_route_distribution_id of this UpdateDrgAttachmentDetails.
        :type: str
        """
        self._export_drg_route_distribution_id = export_drg_route_distribution_id

    @property
    def route_table_id(self):
        """
        Gets the route_table_id of this UpdateDrgAttachmentDetails.
        This is the `OCID`__ of the route table that is used to route the traffic as it enters a VCN through this attachment.

        For information about why you would associate a route table with a DRG attachment, see:

          * `Transit Routing: Access to Multiple VCNs in Same Region`__
          * `Transit Routing: Private Access to Oracle Services`__

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm
        __ https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/transitrouting.htm
        __ https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/transitroutingoracleservices.htm


        :return: The route_table_id of this UpdateDrgAttachmentDetails.
        :rtype: str
        """
        return self._route_table_id

    @route_table_id.setter
    def route_table_id(self, route_table_id):
        """
        Sets the route_table_id of this UpdateDrgAttachmentDetails.
        This is the `OCID`__ of the route table that is used to route the traffic as it enters a VCN through this attachment.

        For information about why you would associate a route table with a DRG attachment, see:

          * `Transit Routing: Access to Multiple VCNs in Same Region`__
          * `Transit Routing: Private Access to Oracle Services`__

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm
        __ https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/transitrouting.htm
        __ https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/transitroutingoracleservices.htm


        :param route_table_id: The route_table_id of this UpdateDrgAttachmentDetails.
        :type: str
        """
        self._route_table_id = route_table_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .eula import Eula
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class TextBasedEula(Eula):
    """
    An end user license agreement that is provided as text.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new TextBasedEula object with values from keyword arguments. The default value of the :py:attr:`~oci.marketplace.models.TextBasedEula.eula_type` attribute
        of this class is ``TEXT`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param eula_type:
            The value to assign to the eula_type property of this TextBasedEula.
            Allowed values for this property are: "TEXT"
        :type eula_type: str

        :param license_text:
            The value to assign to the license_text property of this TextBasedEula.
        :type license_text: str

        """
        self.swagger_types = {
            'eula_type': 'str',
            'license_text': 'str'
        }

        self.attribute_map = {
            'eula_type': 'eulaType',
            'license_text': 'licenseText'
        }

        self._eula_type = None
        self._license_text = None
        self._eula_type = 'TEXT'

    @property
    def license_text(self):
        """
        Gets the license_text of this TextBasedEula.
        The text of the end user license agreement.


        :return: The license_text of this TextBasedEula.
        :rtype: str
        """
        return self._license_text

    @license_text.setter
    def license_text(self, license_text):
        """
        Sets the license_text of this TextBasedEula.
        The text of the end user license agreement.


        :param license_text: The license_text of this TextBasedEula.
        :type: str
        """
        self._license_text = license_text

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Message(object):
    """
    A message in a stream.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new Message object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param stream:
            The value to assign to the stream property of this Message.
        :type stream: str

        :param partition:
            The value to assign to the partition property of this Message.
        :type partition: str

        :param key:
            The value to assign to the key property of this Message.
        :type key: str

        :param value:
            The value to assign to the value property of this Message.
        :type value: str

        :param offset:
            The value to assign to the offset property of this Message.
        :type offset: int

        :param timestamp:
            The value to assign to the timestamp property of this Message.
        :type timestamp: datetime

        """
        self.swagger_types = {
            'stream': 'str',
            'partition': 'str',
            'key': 'str',
            'value': 'str',
            'offset': 'int',
            'timestamp': 'datetime'
        }

        self.attribute_map = {
            'stream': 'stream',
            'partition': 'partition',
            'key': 'key',
            'value': 'value',
            'offset': 'offset',
            'timestamp': 'timestamp'
        }

        self._stream = None
        self._partition = None
        self._key = None
        self._value = None
        self._offset = None
        self._timestamp = None

    @property
    def stream(self):
        """
        **[Required]** Gets the stream of this Message.
        The name of the stream that the message belongs to.


        :return: The stream of this Message.
        :rtype: str
        """
        return self._stream

    @stream.setter
    def stream(self, stream):
        """
        Sets the stream of this Message.
        The name of the stream that the message belongs to.


        :param stream: The stream of this Message.
        :type: str
        """
        self._stream = stream

    @property
    def partition(self):
        """
        **[Required]** Gets the partition of this Message.
        The ID of the partition where the message is stored.


        :return: The partition of this Message.
        :rtype: str
        """
        return self._partition

    @partition.setter
    def partition(self, partition):
        """
        Sets the partition of this Message.
        The ID of the partition where the message is stored.


        :param partition: The partition of this Message.
        :type: str
        """
        self._partition = partition

    @property
    def key(self):
        """
        **[Required]** Gets the key of this Message.
        The key associated with the message, expressed as a byte array.


        :return: The key of this Message.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this Message.
        The key associated with the message, expressed as a byte array.


        :param key: The key of this Message.
        :type: str
        """
        self._key = key

    @property
    def value(self):
        """
        **[Required]** Gets the value of this Message.
        The value associated with the message, expressed as a byte array.


        :return: The value of this Message.
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this Message.
        The value associated with the message, expressed as a byte array.


        :param value: The value of this Message.
        :type: str
        """
        self._value = value

    @property
    def offset(self):
        """
        **[Required]** Gets the offset of this Message.
        The offset of the message, which uniquely identifies it within the partition.


        :return: The offset of this Message.
        :rtype: int
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        """
        Sets the offset of this Message.
        The offset of the message, which uniquely identifies it within the partition.


        :param offset: The offset of this Message.
        :type: int
        """
        self._offset = offset

    @property
    def timestamp(self):
        """
        **[Required]** Gets the timestamp of this Message.
        The timestamp indicating when the server appended the message to the stream.


        :return: The timestamp of this Message.
        :rtype: datetime
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """
        Sets the timestamp of this Message.
        The timestamp indicating when the server appended the message to the stream.


        :param timestamp: The timestamp of this Message.
        :type: datetime
        """
        self._timestamp = timestamp

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateCloudVmClusterDetails(object):
    """
    Details for the create cloud VM cluster operation. Applies to Exadata Cloud Service instances only.
    """

    #: A constant which can be used with the license_model property of a CreateCloudVmClusterDetails.
    #: This constant has a value of "LICENSE_INCLUDED"
    LICENSE_MODEL_LICENSE_INCLUDED = "LICENSE_INCLUDED"

    #: A constant which can be used with the license_model property of a CreateCloudVmClusterDetails.
    #: This constant has a value of "BRING_YOUR_OWN_LICENSE"
    LICENSE_MODEL_BRING_YOUR_OWN_LICENSE = "BRING_YOUR_OWN_LICENSE"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateCloudVmClusterDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateCloudVmClusterDetails.
        :type compartment_id: str

        :param subnet_id:
            The value to assign to the subnet_id property of this CreateCloudVmClusterDetails.
        :type subnet_id: str

        :param backup_subnet_id:
            The value to assign to the backup_subnet_id property of this CreateCloudVmClusterDetails.
        :type backup_subnet_id: str

        :param cpu_core_count:
            The value to assign to the cpu_core_count property of this CreateCloudVmClusterDetails.
        :type cpu_core_count: int

        :param cluster_name:
            The value to assign to the cluster_name property of this CreateCloudVmClusterDetails.
        :type cluster_name: str

        :param data_storage_percentage:
            The value to assign to the data_storage_percentage property of this CreateCloudVmClusterDetails.
        :type data_storage_percentage: int

        :param display_name:
            The value to assign to the display_name property of this CreateCloudVmClusterDetails.
        :type display_name: str

        :param cloud_exadata_infrastructure_id:
            The value to assign to the cloud_exadata_infrastructure_id property of this CreateCloudVmClusterDetails.
        :type cloud_exadata_infrastructure_id: str

        :param hostname:
            The value to assign to the hostname property of this CreateCloudVmClusterDetails.
        :type hostname: str

        :param domain:
            The value to assign to the domain property of this CreateCloudVmClusterDetails.
        :type domain: str

        :param ssh_public_keys:
            The value to assign to the ssh_public_keys property of this CreateCloudVmClusterDetails.
        :type ssh_public_keys: list[str]

        :param license_model:
            The value to assign to the license_model property of this CreateCloudVmClusterDetails.
            Allowed values for this property are: "LICENSE_INCLUDED", "BRING_YOUR_OWN_LICENSE"
        :type license_model: str

        :param is_sparse_diskgroup_enabled:
            The value to assign to the is_sparse_diskgroup_enabled property of this CreateCloudVmClusterDetails.
        :type is_sparse_diskgroup_enabled: bool

        :param is_local_backup_enabled:
            The value to assign to the is_local_backup_enabled property of this CreateCloudVmClusterDetails.
        :type is_local_backup_enabled: bool

        :param time_zone:
            The value to assign to the time_zone property of this CreateCloudVmClusterDetails.
        :type time_zone: str

        :param nsg_ids:
            The value to assign to the nsg_ids property of this CreateCloudVmClusterDetails.
        :type nsg_ids: list[str]

        :param backup_network_nsg_ids:
            The value to assign to the backup_network_nsg_ids property of this CreateCloudVmClusterDetails.
        :type backup_network_nsg_ids: list[str]

        :param gi_version:
            The value to assign to the gi_version property of this CreateCloudVmClusterDetails.
        :type gi_version: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateCloudVmClusterDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateCloudVmClusterDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'subnet_id': 'str',
            'backup_subnet_id': 'str',
            'cpu_core_count': 'int',
            'cluster_name': 'str',
            'data_storage_percentage': 'int',
            'display_name': 'str',
            'cloud_exadata_infrastructure_id': 'str',
            'hostname': 'str',
            'domain': 'str',
            'ssh_public_keys': 'list[str]',
            'license_model': 'str',
            'is_sparse_diskgroup_enabled': 'bool',
            'is_local_backup_enabled': 'bool',
            'time_zone': 'str',
            'nsg_ids': 'list[str]',
            'backup_network_nsg_ids': 'list[str]',
            'gi_version': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'subnet_id': 'subnetId',
            'backup_subnet_id': 'backupSubnetId',
            'cpu_core_count': 'cpuCoreCount',
            'cluster_name': 'clusterName',
            'data_storage_percentage': 'dataStoragePercentage',
            'display_name': 'displayName',
            'cloud_exadata_infrastructure_id': 'cloudExadataInfrastructureId',
            'hostname': 'hostname',
            'domain': 'domain',
            'ssh_public_keys': 'sshPublicKeys',
            'license_model': 'licenseModel',
            'is_sparse_diskgroup_enabled': 'isSparseDiskgroupEnabled',
            'is_local_backup_enabled': 'isLocalBackupEnabled',
            'time_zone': 'timeZone',
            'nsg_ids': 'nsgIds',
            'backup_network_nsg_ids': 'backupNetworkNsgIds',
            'gi_version': 'giVersion',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._compartment_id = None
        self._subnet_id = None
        self._backup_subnet_id = None
        self._cpu_core_count = None
        self._cluster_name = None
        self._data_storage_percentage = None
        self._display_name = None
        self._cloud_exadata_infrastructure_id = None
        self._hostname = None
        self._domain = None
        self._ssh_public_keys = None
        self._license_model = None
        self._is_sparse_diskgroup_enabled = None
        self._is_local_backup_enabled = None
        self._time_zone = None
        self._nsg_ids = None
        self._backup_network_nsg_ids = None
        self._gi_version = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateCloudVmClusterDetails.
        The `OCID`__ of the compartment.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this CreateCloudVmClusterDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateCloudVmClusterDetails.
        The `OCID`__ of the compartment.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this CreateCloudVmClusterDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def subnet_id(self):
        """
        **[Required]** Gets the subnet_id of this CreateCloudVmClusterDetails.
        The `OCID`__ of the subnet associated with the cloud VM cluster.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The subnet_id of this CreateCloudVmClusterDetails.
        :rtype: str
        """
        return self._subnet_id

    @subnet_id.setter
    def subnet_id(self, subnet_id):
        """
        Sets the subnet_id of this CreateCloudVmClusterDetails.
        The `OCID`__ of the subnet associated with the cloud VM cluster.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param subnet_id: The subnet_id of this CreateCloudVmClusterDetails.
        :type: str
        """
        self._subnet_id = subnet_id

    @property
    def backup_subnet_id(self):
        """
        **[Required]** Gets the backup_subnet_id of this CreateCloudVmClusterDetails.
        The `OCID`__ of the backup network subnet associated with the cloud VM cluster.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The backup_subnet_id of this CreateCloudVmClusterDetails.
        :rtype: str
        """
        return self._backup_subnet_id

    @backup_subnet_id.setter
    def backup_subnet_id(self, backup_subnet_id):
        """
        Sets the backup_subnet_id of this CreateCloudVmClusterDetails.
        The `OCID`__ of the backup network subnet associated with the cloud VM cluster.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param backup_subnet_id: The backup_subnet_id of this CreateCloudVmClusterDetails.
        :type: str
        """
        self._backup_subnet_id = backup_subnet_id

    @property
    def cpu_core_count(self):
        """
        **[Required]** Gets the cpu_core_count of this CreateCloudVmClusterDetails.
        The number of CPU cores to enable for a cloud VM cluster. Valid values depend on the specified shape:

        - Exadata.Base.48 - Specify a multiple of 2, from 0 to 48.
        - Exadata.Quarter1.84 - Specify a multiple of 2, from 22 to 84.
        - Exadata.Half1.168 - Specify a multiple of 4, from 44 to 168.
        - Exadata.Full1.336 - Specify a multiple of 8, from 88 to 336.
        - Exadata.Quarter2.92 - Specify a multiple of 2, from 0 to 92.
        - Exadata.Half2.184 - Specify a multiple of 4, from 0 to 184.
        - Exadata.Full2.368 - Specify a multiple of 8, from 0 to 368.


        :return: The cpu_core_count of this CreateCloudVmClusterDetails.
        :rtype: int
        """
        return self._cpu_core_count

    @cpu_core_count.setter
    def cpu_core_count(self, cpu_core_count):
        """
        Sets the cpu_core_count of this CreateCloudVmClusterDetails.
        The number of CPU cores to enable for a cloud VM cluster. Valid values depend on the specified shape:

        - Exadata.Base.48 - Specify a multiple of 2, from 0 to 48.
        - Exadata.Quarter1.84 - Specify a multiple of 2, from 22 to 84.
        - Exadata.Half1.168 - Specify a multiple of 4, from 44 to 168.
        - Exadata.Full1.336 - Specify a multiple of 8, from 88 to 336.
        - Exadata.Quarter2.92 - Specify a multiple of 2, from 0 to 92.
        - Exadata.Half2.184 - Specify a multiple of 4, from 0 to 184.
        - Exadata.Full2.368 - Specify a multiple of 8, from 0 to 368.


        :param cpu_core_count: The cpu_core_count of this CreateCloudVmClusterDetails.
        :type: int
        """
        self._cpu_core_count = cpu_core_count

    @property
    def cluster_name(self):
        """
        Gets the cluster_name of this CreateCloudVmClusterDetails.
        The cluster name for cloud VM cluster. The cluster name must begin with an alphabetic character, and may contain hyphens (-). Underscores (_) are not permitted. The cluster name can be no longer than 11 characters and is not case sensitive.


        :return: The cluster_name of this CreateCloudVmClusterDetails.
        :rtype: str
        """
        return self._cluster_name

    @cluster_name.setter
    def cluster_name(self, cluster_name):
        """
        Sets the cluster_name of this CreateCloudVmClusterDetails.
        The cluster name for cloud VM cluster. The cluster name must begin with an alphabetic character, and may contain hyphens (-). Underscores (_) are not permitted. The cluster name can be no longer than 11 characters and is not case sensitive.


        :param cluster_name: The cluster_name of this CreateCloudVmClusterDetails.
        :type: str
        """
        self._cluster_name = cluster_name

    @property
    def data_storage_percentage(self):
        """
        Gets the data_storage_percentage of this CreateCloudVmClusterDetails.
        The percentage assigned to DATA storage (user data and database files).
        The remaining percentage is assigned to RECO storage (database redo logs, archive logs, and recovery manager backups). Accepted values are 35, 40, 60 and 80. The default is 80 percent assigned to DATA storage. See `Storage Configuration`__ in the Exadata documentation for details on the impact of the configuration settings on storage.

        __ https://docs.cloud.oracle.com/Content/Database/Concepts/exaoverview.htm#Exadata


        :return: The data_storage_percentage of this CreateCloudVmClusterDetails.
        :rtype: int
        """
        return self._data_storage_percentage

    @data_storage_percentage.setter
    def data_storage_percentage(self, data_storage_percentage):
        """
        Sets the data_storage_percentage of this CreateCloudVmClusterDetails.
        The percentage assigned to DATA storage (user data and database files).
        The remaining percentage is assigned to RECO storage (database redo logs, archive logs, and recovery manager backups). Accepted values are 35, 40, 60 and 80. The default is 80 percent assigned to DATA storage. See `Storage Configuration`__ in the Exadata documentation for details on the impact of the configuration settings on storage.

        __ https://docs.cloud.oracle.com/Content/Database/Concepts/exaoverview.htm#Exadata


        :param data_storage_percentage: The data_storage_percentage of this CreateCloudVmClusterDetails.
        :type: int
        """
        self._data_storage_percentage = data_storage_percentage

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this CreateCloudVmClusterDetails.
        The user-friendly name for the cloud VM cluster. The name does not need to be unique.


        :return: The display_name of this CreateCloudVmClusterDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateCloudVmClusterDetails.
        The user-friendly name for the cloud VM cluster. The name does not need to be unique.


        :param display_name: The display_name of this CreateCloudVmClusterDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def cloud_exadata_infrastructure_id(self):
        """
        **[Required]** Gets the cloud_exadata_infrastructure_id of this CreateCloudVmClusterDetails.
        The `OCID`__ of the cloud Exadata infrastructure resource.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The cloud_exadata_infrastructure_id of this CreateCloudVmClusterDetails.
        :rtype: str
        """
        return self._cloud_exadata_infrastructure_id

    @cloud_exadata_infrastructure_id.setter
    def cloud_exadata_infrastructure_id(self, cloud_exadata_infrastructure_id):
        """
        Sets the cloud_exadata_infrastructure_id of this CreateCloudVmClusterDetails.
        The `OCID`__ of the cloud Exadata infrastructure resource.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param cloud_exadata_infrastructure_id: The cloud_exadata_infrastructure_id of this CreateCloudVmClusterDetails.
        :type: str
        """
        self._cloud_exadata_infrastructure_id = cloud_exadata_infrastructure_id

    @property
    def hostname(self):
        """
        **[Required]** Gets the hostname of this CreateCloudVmClusterDetails.
        The hostname for the cloud VM cluster. The hostname must begin with an alphabetic character, and
        can contain alphanumeric characters and hyphens (-). The maximum length of the hostname is 16 characters for bare metal and virtual machine DB systems, and 12 characters for Exadata systems.

        The maximum length of the combined hostname and domain is 63 characters.

        **Note:** The hostname must be unique within the subnet. If it is not unique,
        the cloud VM Cluster will fail to provision.


        :return: The hostname of this CreateCloudVmClusterDetails.
        :rtype: str
        """
        return self._hostname

    @hostname.setter
    def hostname(self, hostname):
        """
        Sets the hostname of this CreateCloudVmClusterDetails.
        The hostname for the cloud VM cluster. The hostname must begin with an alphabetic character, and
        can contain alphanumeric characters and hyphens (-). The maximum length of the hostname is 16 characters for bare metal and virtual machine DB systems, and 12 characters for Exadata systems.

        The maximum length of the combined hostname and domain is 63 characters.

        **Note:** The hostname must be unique within the subnet. If it is not unique,
        the cloud VM Cluster will fail to provision.


        :param hostname: The hostname of this CreateCloudVmClusterDetails.
        :type: str
        """
        self._hostname = hostname

    @property
    def domain(self):
        """
        Gets the domain of this CreateCloudVmClusterDetails.
        A domain name used for the cloud VM cluster. If the Oracle-provided internet and VCN
        resolver is enabled for the specified subnet, the domain name for the subnet is used
        (do not provide one). Otherwise, provide a valid DNS domain name. Hyphens (-) are not permitted.
        Applies to Exadata Cloud Service instances only.


        :return: The domain of this CreateCloudVmClusterDetails.
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """
        Sets the domain of this CreateCloudVmClusterDetails.
        A domain name used for the cloud VM cluster. If the Oracle-provided internet and VCN
        resolver is enabled for the specified subnet, the domain name for the subnet is used
        (do not provide one). Otherwise, provide a valid DNS domain name. Hyphens (-) are not permitted.
        Applies to Exadata Cloud Service instances only.


        :param domain: The domain of this CreateCloudVmClusterDetails.
        :type: str
        """
        self._domain = domain

    @property
    def ssh_public_keys(self):
        """
        **[Required]** Gets the ssh_public_keys of this CreateCloudVmClusterDetails.
        The public key portion of one or more key pairs used for SSH access to the cloud VM cluster.


        :return: The ssh_public_keys of this CreateCloudVmClusterDetails.
        :rtype: list[str]
        """
        return self._ssh_public_keys

    @ssh_public_keys.setter
    def ssh_public_keys(self, ssh_public_keys):
        """
        Sets the ssh_public_keys of this CreateCloudVmClusterDetails.
        The public key portion of one or more key pairs used for SSH access to the cloud VM cluster.


        :param ssh_public_keys: The ssh_public_keys of this CreateCloudVmClusterDetails.
        :type: list[str]
        """
        self._ssh_public_keys = ssh_public_keys

    @property
    def license_model(self):
        """
        Gets the license_model of this CreateCloudVmClusterDetails.
        The Oracle license model that applies to the cloud VM cluster. The default is BRING_YOUR_OWN_LICENSE.

        Allowed values for this property are: "LICENSE_INCLUDED", "BRING_YOUR_OWN_LICENSE"


        :return: The license_model of this CreateCloudVmClusterDetails.
        :rtype: str
        """
        return self._license_model

    @license_model.setter
    def license_model(self, license_model):
        """
        Sets the license_model of this CreateCloudVmClusterDetails.
        The Oracle license model that applies to the cloud VM cluster. The default is BRING_YOUR_OWN_LICENSE.


        :param license_model: The license_model of this CreateCloudVmClusterDetails.
        :type: str
        """
        allowed_values = ["LICENSE_INCLUDED", "BRING_YOUR_OWN_LICENSE"]
        if not value_allowed_none_or_none_sentinel(license_model, allowed_values):
            raise ValueError(
                "Invalid value for `license_model`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._license_model = license_model

    @property
    def is_sparse_diskgroup_enabled(self):
        """
        Gets the is_sparse_diskgroup_enabled of this CreateCloudVmClusterDetails.
        If true, the sparse disk group is configured for the cloud VM cluster. If false, the sparse disk group is not created.


        :return: The is_sparse_diskgroup_enabled of this CreateCloudVmClusterDetails.
        :rtype: bool
        """
        return self._is_sparse_diskgroup_enabled

    @is_sparse_diskgroup_enabled.setter
    def is_sparse_diskgroup_enabled(self, is_sparse_diskgroup_enabled):
        """
        Sets the is_sparse_diskgroup_enabled of this CreateCloudVmClusterDetails.
        If true, the sparse disk group is configured for the cloud VM cluster. If false, the sparse disk group is not created.


        :param is_sparse_diskgroup_enabled: The is_sparse_diskgroup_enabled of this CreateCloudVmClusterDetails.
        :type: bool
        """
        self._is_sparse_diskgroup_enabled = is_sparse_diskgroup_enabled

    @property
    def is_local_backup_enabled(self):
        """
        Gets the is_local_backup_enabled of this CreateCloudVmClusterDetails.
        If true, database backup on local Exadata storage is configured for the cloud VM cluster. If false, database backup on local Exadata storage is not available in the cloud VM cluster.


        :return: The is_local_backup_enabled of this CreateCloudVmClusterDetails.
        :rtype: bool
        """
        return self._is_local_backup_enabled

    @is_local_backup_enabled.setter
    def is_local_backup_enabled(self, is_local_backup_enabled):
        """
        Sets the is_local_backup_enabled of this CreateCloudVmClusterDetails.
        If true, database backup on local Exadata storage is configured for the cloud VM cluster. If false, database backup on local Exadata storage is not available in the cloud VM cluster.


        :param is_local_backup_enabled: The is_local_backup_enabled of this CreateCloudVmClusterDetails.
        :type: bool
        """
        self._is_local_backup_enabled = is_local_backup_enabled

    @property
    def time_zone(self):
        """
        Gets the time_zone of this CreateCloudVmClusterDetails.
        The time zone to use for the cloud VM cluster. For details, see `Time Zones`__.

        __ https://docs.cloud.oracle.com/Content/Database/References/timezones.htm


        :return: The time_zone of this CreateCloudVmClusterDetails.
        :rtype: str
        """
        return self._time_zone

    @time_zone.setter
    def time_zone(self, time_zone):
        """
        Sets the time_zone of this CreateCloudVmClusterDetails.
        The time zone to use for the cloud VM cluster. For details, see `Time Zones`__.

        __ https://docs.cloud.oracle.com/Content/Database/References/timezones.htm


        :param time_zone: The time_zone of this CreateCloudVmClusterDetails.
        :type: str
        """
        self._time_zone = time_zone

    @property
    def nsg_ids(self):
        """
        Gets the nsg_ids of this CreateCloudVmClusterDetails.
        A list of the `OCIDs`__ of the network security groups (NSGs) that this resource belongs to. Setting this to an empty array after the list is created removes the resource from all NSGs. For more information about NSGs, see `Security Rules`__.
        **NsgIds restrictions:**
        - Autonomous Databases with private access require at least 1 Network Security Group (NSG). The nsgIds array cannot be empty.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm
        __ https://docs.cloud.oracle.com/Content/Network/Concepts/securityrules.htm


        :return: The nsg_ids of this CreateCloudVmClusterDetails.
        :rtype: list[str]
        """
        return self._nsg_ids

    @nsg_ids.setter
    def nsg_ids(self, nsg_ids):
        """
        Sets the nsg_ids of this CreateCloudVmClusterDetails.
        A list of the `OCIDs`__ of the network security groups (NSGs) that this resource belongs to. Setting this to an empty array after the list is created removes the resource from all NSGs. For more information about NSGs, see `Security Rules`__.
        **NsgIds restrictions:**
        - Autonomous Databases with private access require at least 1 Network Security Group (NSG). The nsgIds array cannot be empty.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm
        __ https://docs.cloud.oracle.com/Content/Network/Concepts/securityrules.htm


        :param nsg_ids: The nsg_ids of this CreateCloudVmClusterDetails.
        :type: list[str]
        """
        self._nsg_ids = nsg_ids

    @property
    def backup_network_nsg_ids(self):
        """
        Gets the backup_network_nsg_ids of this CreateCloudVmClusterDetails.
        A list of the `OCIDs`__ of the network security groups (NSGs) that the backup network of this DB system belongs to. Setting this to an empty array after the list is created removes the resource from all NSGs. For more information about NSGs, see `Security Rules`__. Applicable only to Exadata systems.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm
        __ https://docs.cloud.oracle.com/Content/Network/Concepts/securityrules.htm


        :return: The backup_network_nsg_ids of this CreateCloudVmClusterDetails.
        :rtype: list[str]
        """
        return self._backup_network_nsg_ids

    @backup_network_nsg_ids.setter
    def backup_network_nsg_ids(self, backup_network_nsg_ids):
        """
        Sets the backup_network_nsg_ids of this CreateCloudVmClusterDetails.
        A list of the `OCIDs`__ of the network security groups (NSGs) that the backup network of this DB system belongs to. Setting this to an empty array after the list is created removes the resource from all NSGs. For more information about NSGs, see `Security Rules`__. Applicable only to Exadata systems.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm
        __ https://docs.cloud.oracle.com/Content/Network/Concepts/securityrules.htm


        :param backup_network_nsg_ids: The backup_network_nsg_ids of this CreateCloudVmClusterDetails.
        :type: list[str]
        """
        self._backup_network_nsg_ids = backup_network_nsg_ids

    @property
    def gi_version(self):
        """
        **[Required]** Gets the gi_version of this CreateCloudVmClusterDetails.
        A valid Oracle Grid Infrastructure (GI) software version.


        :return: The gi_version of this CreateCloudVmClusterDetails.
        :rtype: str
        """
        return self._gi_version

    @gi_version.setter
    def gi_version(self, gi_version):
        """
        Sets the gi_version of this CreateCloudVmClusterDetails.
        A valid Oracle Grid Infrastructure (GI) software version.


        :param gi_version: The gi_version of this CreateCloudVmClusterDetails.
        :type: str
        """
        self._gi_version = gi_version

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateCloudVmClusterDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this CreateCloudVmClusterDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateCloudVmClusterDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this CreateCloudVmClusterDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateCloudVmClusterDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this CreateCloudVmClusterDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateCloudVmClusterDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this CreateCloudVmClusterDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .task_summary import TaskSummary
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class TaskSummaryFromIntegrationTask(TaskSummary):
    """
    The information about the integration task.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new TaskSummaryFromIntegrationTask object with values from keyword arguments. The default value of the :py:attr:`~oci.data_integration.models.TaskSummaryFromIntegrationTask.model_type` attribute
        of this class is ``INTEGRATION_TASK`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_type:
            The value to assign to the model_type property of this TaskSummaryFromIntegrationTask.
            Allowed values for this property are: "INTEGRATION_TASK", "DATA_LOADER_TASK", "PIPELINE_TASK", "SQL_TASK", "OCI_DATAFLOW_TASK", "REST_TASK"
        :type model_type: str

        :param key:
            The value to assign to the key property of this TaskSummaryFromIntegrationTask.
        :type key: str

        :param model_version:
            The value to assign to the model_version property of this TaskSummaryFromIntegrationTask.
        :type model_version: str

        :param parent_ref:
            The value to assign to the parent_ref property of this TaskSummaryFromIntegrationTask.
        :type parent_ref: oci.data_integration.models.ParentReference

        :param name:
            The value to assign to the name property of this TaskSummaryFromIntegrationTask.
        :type name: str

        :param description:
            The value to assign to the description property of this TaskSummaryFromIntegrationTask.
        :type description: str

        :param object_version:
            The value to assign to the object_version property of this TaskSummaryFromIntegrationTask.
        :type object_version: int

        :param object_status:
            The value to assign to the object_status property of this TaskSummaryFromIntegrationTask.
        :type object_status: int

        :param identifier:
            The value to assign to the identifier property of this TaskSummaryFromIntegrationTask.
        :type identifier: str

        :param input_ports:
            The value to assign to the input_ports property of this TaskSummaryFromIntegrationTask.
        :type input_ports: list[oci.data_integration.models.InputPort]

        :param output_ports:
            The value to assign to the output_ports property of this TaskSummaryFromIntegrationTask.
        :type output_ports: list[oci.data_integration.models.OutputPort]

        :param parameters:
            The value to assign to the parameters property of this TaskSummaryFromIntegrationTask.
        :type parameters: list[oci.data_integration.models.Parameter]

        :param op_config_values:
            The value to assign to the op_config_values property of this TaskSummaryFromIntegrationTask.
        :type op_config_values: oci.data_integration.models.ConfigValues

        :param config_provider_delegate:
            The value to assign to the config_provider_delegate property of this TaskSummaryFromIntegrationTask.
        :type config_provider_delegate: oci.data_integration.models.ConfigProvider

        :param metadata:
            The value to assign to the metadata property of this TaskSummaryFromIntegrationTask.
        :type metadata: oci.data_integration.models.ObjectMetadata

        :param key_map:
            The value to assign to the key_map property of this TaskSummaryFromIntegrationTask.
        :type key_map: dict(str, str)

        :param data_flow:
            The value to assign to the data_flow property of this TaskSummaryFromIntegrationTask.
        :type data_flow: oci.data_integration.models.DataFlow

        """
        self.swagger_types = {
            'model_type': 'str',
            'key': 'str',
            'model_version': 'str',
            'parent_ref': 'ParentReference',
            'name': 'str',
            'description': 'str',
            'object_version': 'int',
            'object_status': 'int',
            'identifier': 'str',
            'input_ports': 'list[InputPort]',
            'output_ports': 'list[OutputPort]',
            'parameters': 'list[Parameter]',
            'op_config_values': 'ConfigValues',
            'config_provider_delegate': 'ConfigProvider',
            'metadata': 'ObjectMetadata',
            'key_map': 'dict(str, str)',
            'data_flow': 'DataFlow'
        }

        self.attribute_map = {
            'model_type': 'modelType',
            'key': 'key',
            'model_version': 'modelVersion',
            'parent_ref': 'parentRef',
            'name': 'name',
            'description': 'description',
            'object_version': 'objectVersion',
            'object_status': 'objectStatus',
            'identifier': 'identifier',
            'input_ports': 'inputPorts',
            'output_ports': 'outputPorts',
            'parameters': 'parameters',
            'op_config_values': 'opConfigValues',
            'config_provider_delegate': 'configProviderDelegate',
            'metadata': 'metadata',
            'key_map': 'keyMap',
            'data_flow': 'dataFlow'
        }

        self._model_type = None
        self._key = None
        self._model_version = None
        self._parent_ref = None
        self._name = None
        self._description = None
        self._object_version = None
        self._object_status = None
        self._identifier = None
        self._input_ports = None
        self._output_ports = None
        self._parameters = None
        self._op_config_values = None
        self._config_provider_delegate = None
        self._metadata = None
        self._key_map = None
        self._data_flow = None
        self._model_type = 'INTEGRATION_TASK'

    @property
    def data_flow(self):
        """
        Gets the data_flow of this TaskSummaryFromIntegrationTask.

        :return: The data_flow of this TaskSummaryFromIntegrationTask.
        :rtype: oci.data_integration.models.DataFlow
        """
        return self._data_flow

    @data_flow.setter
    def data_flow(self, data_flow):
        """
        Sets the data_flow of this TaskSummaryFromIntegrationTask.

        :param data_flow: The data_flow of this TaskSummaryFromIntegrationTask.
        :type: oci.data_integration.models.DataFlow
        """
        self._data_flow = data_flow

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .publication_package import PublicationPackage
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ImagePublicationPackage(PublicationPackage):
    """
    A publication package for image publications.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ImagePublicationPackage object with values from keyword arguments. The default value of the :py:attr:`~oci.marketplace.models.ImagePublicationPackage.package_type` attribute
        of this class is ``IMAGE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param description:
            The value to assign to the description property of this ImagePublicationPackage.
        :type description: str

        :param listing_id:
            The value to assign to the listing_id property of this ImagePublicationPackage.
        :type listing_id: str

        :param version:
            The value to assign to the version property of this ImagePublicationPackage.
        :type version: str

        :param package_type:
            The value to assign to the package_type property of this ImagePublicationPackage.
            Allowed values for this property are: "ORCHESTRATION", "IMAGE"
        :type package_type: str

        :param resource_id:
            The value to assign to the resource_id property of this ImagePublicationPackage.
        :type resource_id: str

        :param time_created:
            The value to assign to the time_created property of this ImagePublicationPackage.
        :type time_created: datetime

        :param operating_system:
            The value to assign to the operating_system property of this ImagePublicationPackage.
        :type operating_system: oci.marketplace.models.OperatingSystem

        :param app_catalog_listing_id:
            The value to assign to the app_catalog_listing_id property of this ImagePublicationPackage.
        :type app_catalog_listing_id: str

        :param app_catalog_listing_resource_version:
            The value to assign to the app_catalog_listing_resource_version property of this ImagePublicationPackage.
        :type app_catalog_listing_resource_version: str

        :param image_id:
            The value to assign to the image_id property of this ImagePublicationPackage.
        :type image_id: str

        """
        self.swagger_types = {
            'description': 'str',
            'listing_id': 'str',
            'version': 'str',
            'package_type': 'str',
            'resource_id': 'str',
            'time_created': 'datetime',
            'operating_system': 'OperatingSystem',
            'app_catalog_listing_id': 'str',
            'app_catalog_listing_resource_version': 'str',
            'image_id': 'str'
        }

        self.attribute_map = {
            'description': 'description',
            'listing_id': 'listingId',
            'version': 'version',
            'package_type': 'packageType',
            'resource_id': 'resourceId',
            'time_created': 'timeCreated',
            'operating_system': 'operatingSystem',
            'app_catalog_listing_id': 'appCatalogListingId',
            'app_catalog_listing_resource_version': 'appCatalogListingResourceVersion',
            'image_id': 'imageId'
        }

        self._description = None
        self._listing_id = None
        self._version = None
        self._package_type = None
        self._resource_id = None
        self._time_created = None
        self._operating_system = None
        self._app_catalog_listing_id = None
        self._app_catalog_listing_resource_version = None
        self._image_id = None
        self._package_type = 'IMAGE'

    @property
    def app_catalog_listing_id(self):
        """
        Gets the app_catalog_listing_id of this ImagePublicationPackage.
        The ID of the listing resource associated with this publication package. For more information, see `AppCatalogListing`__ in the Core Services API.

        __ https://docs.cloud.oracle.com/en-us/iaas/api/#/en/iaas/latest/AppCatalogListing/


        :return: The app_catalog_listing_id of this ImagePublicationPackage.
        :rtype: str
        """
        return self._app_catalog_listing_id

    @app_catalog_listing_id.setter
    def app_catalog_listing_id(self, app_catalog_listing_id):
        """
        Sets the app_catalog_listing_id of this ImagePublicationPackage.
        The ID of the listing resource associated with this publication package. For more information, see `AppCatalogListing`__ in the Core Services API.

        __ https://docs.cloud.oracle.com/en-us/iaas/api/#/en/iaas/latest/AppCatalogListing/


        :param app_catalog_listing_id: The app_catalog_listing_id of this ImagePublicationPackage.
        :type: str
        """
        self._app_catalog_listing_id = app_catalog_listing_id

    @property
    def app_catalog_listing_resource_version(self):
        """
        Gets the app_catalog_listing_resource_version of this ImagePublicationPackage.
        The resource version of the listing resource associated with this publication package.


        :return: The app_catalog_listing_resource_version of this ImagePublicationPackage.
        :rtype: str
        """
        return self._app_catalog_listing_resource_version

    @app_catalog_listing_resource_version.setter
    def app_catalog_listing_resource_version(self, app_catalog_listing_resource_version):
        """
        Sets the app_catalog_listing_resource_version of this ImagePublicationPackage.
        The resource version of the listing resource associated with this publication package.


        :param app_catalog_listing_resource_version: The app_catalog_listing_resource_version of this ImagePublicationPackage.
        :type: str
        """
        self._app_catalog_listing_resource_version = app_catalog_listing_resource_version

    @property
    def image_id(self):
        """
        Gets the image_id of this ImagePublicationPackage.
        The ID of the image that corresponds to the package.


        :return: The image_id of this ImagePublicationPackage.
        :rtype: str
        """
        return self._image_id

    @image_id.setter
    def image_id(self, image_id):
        """
        Sets the image_id of this ImagePublicationPackage.
        The ID of the image that corresponds to the package.


        :param image_id: The image_id of this ImagePublicationPackage.
        :type: str
        """
        self._image_id = image_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ResourceCapacityTrendAggregation(object):
    """
    Resource Capacity samples
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ResourceCapacityTrendAggregation object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param end_timestamp:
            The value to assign to the end_timestamp property of this ResourceCapacityTrendAggregation.
        :type end_timestamp: datetime

        :param capacity:
            The value to assign to the capacity property of this ResourceCapacityTrendAggregation.
        :type capacity: float

        :param base_capacity:
            The value to assign to the base_capacity property of this ResourceCapacityTrendAggregation.
        :type base_capacity: float

        """
        self.swagger_types = {
            'end_timestamp': 'datetime',
            'capacity': 'float',
            'base_capacity': 'float'
        }

        self.attribute_map = {
            'end_timestamp': 'endTimestamp',
            'capacity': 'capacity',
            'base_capacity': 'baseCapacity'
        }

        self._end_timestamp = None
        self._capacity = None
        self._base_capacity = None

    @property
    def end_timestamp(self):
        """
        **[Required]** Gets the end_timestamp of this ResourceCapacityTrendAggregation.
        The timestamp in which the current sampling period ends in RFC 3339 format.


        :return: The end_timestamp of this ResourceCapacityTrendAggregation.
        :rtype: datetime
        """
        return self._end_timestamp

    @end_timestamp.setter
    def end_timestamp(self, end_timestamp):
        """
        Sets the end_timestamp of this ResourceCapacityTrendAggregation.
        The timestamp in which the current sampling period ends in RFC 3339 format.


        :param end_timestamp: The end_timestamp of this ResourceCapacityTrendAggregation.
        :type: datetime
        """
        self._end_timestamp = end_timestamp

    @property
    def capacity(self):
        """
        **[Required]** Gets the capacity of this ResourceCapacityTrendAggregation.
        The maximum allocated amount of the resource metric type  (CPU, STORAGE).


        :return: The capacity of this ResourceCapacityTrendAggregation.
        :rtype: float
        """
        return self._capacity

    @capacity.setter
    def capacity(self, capacity):
        """
        Sets the capacity of this ResourceCapacityTrendAggregation.
        The maximum allocated amount of the resource metric type  (CPU, STORAGE).


        :param capacity: The capacity of this ResourceCapacityTrendAggregation.
        :type: float
        """
        self._capacity = capacity

    @property
    def base_capacity(self):
        """
        **[Required]** Gets the base_capacity of this ResourceCapacityTrendAggregation.
        The base allocated amount of the resource metric type  (CPU, STORAGE).


        :return: The base_capacity of this ResourceCapacityTrendAggregation.
        :rtype: float
        """
        return self._base_capacity

    @base_capacity.setter
    def base_capacity(self, base_capacity):
        """
        Sets the base_capacity of this ResourceCapacityTrendAggregation.
        The base allocated amount of the resource metric type  (CPU, STORAGE).


        :param base_capacity: The base_capacity of this ResourceCapacityTrendAggregation.
        :type: float
        """
        self._base_capacity = base_capacity

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Term(object):
    """
    Full term definition. A defined business term in a business glossary. As well as a term definition, simple format
    rules for attributes mapping to the term (for example, the expected data type and length restrictions) may be
    stated at the term level. Nesting of terms to support a hierarchy is supported by default.
    """

    #: A constant which can be used with the lifecycle_state property of a Term.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a Term.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a Term.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    #: A constant which can be used with the lifecycle_state property of a Term.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a Term.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a Term.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a Term.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the lifecycle_state property of a Term.
    #: This constant has a value of "MOVING"
    LIFECYCLE_STATE_MOVING = "MOVING"

    #: A constant which can be used with the workflow_status property of a Term.
    #: This constant has a value of "NEW"
    WORKFLOW_STATUS_NEW = "NEW"

    #: A constant which can be used with the workflow_status property of a Term.
    #: This constant has a value of "APPROVED"
    WORKFLOW_STATUS_APPROVED = "APPROVED"

    #: A constant which can be used with the workflow_status property of a Term.
    #: This constant has a value of "UNDER_REVIEW"
    WORKFLOW_STATUS_UNDER_REVIEW = "UNDER_REVIEW"

    #: A constant which can be used with the workflow_status property of a Term.
    #: This constant has a value of "ESCALATED"
    WORKFLOW_STATUS_ESCALATED = "ESCALATED"

    def __init__(self, **kwargs):
        """
        Initializes a new Term object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key:
            The value to assign to the key property of this Term.
        :type key: str

        :param display_name:
            The value to assign to the display_name property of this Term.
        :type display_name: str

        :param description:
            The value to assign to the description property of this Term.
        :type description: str

        :param glossary_key:
            The value to assign to the glossary_key property of this Term.
        :type glossary_key: str

        :param parent_term_key:
            The value to assign to the parent_term_key property of this Term.
        :type parent_term_key: str

        :param is_allowed_to_have_child_terms:
            The value to assign to the is_allowed_to_have_child_terms property of this Term.
        :type is_allowed_to_have_child_terms: bool

        :param path:
            The value to assign to the path property of this Term.
        :type path: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this Term.
            Allowed values for this property are: "CREATING", "ACTIVE", "INACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED", "MOVING", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param time_created:
            The value to assign to the time_created property of this Term.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this Term.
        :type time_updated: datetime

        :param created_by_id:
            The value to assign to the created_by_id property of this Term.
        :type created_by_id: str

        :param updated_by_id:
            The value to assign to the updated_by_id property of this Term.
        :type updated_by_id: str

        :param owner:
            The value to assign to the owner property of this Term.
        :type owner: str

        :param workflow_status:
            The value to assign to the workflow_status property of this Term.
            Allowed values for this property are: "NEW", "APPROVED", "UNDER_REVIEW", "ESCALATED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type workflow_status: str

        :param uri:
            The value to assign to the uri property of this Term.
        :type uri: str

        :param associated_object_count:
            The value to assign to the associated_object_count property of this Term.
        :type associated_object_count: int

        :param associated_objects:
            The value to assign to the associated_objects property of this Term.
        :type associated_objects: list[oci.data_catalog.models.TermAssociatedObject]

        :param custom_property_members:
            The value to assign to the custom_property_members property of this Term.
        :type custom_property_members: list[oci.data_catalog.models.CustomPropertyGetUsage]

        """
        self.swagger_types = {
            'key': 'str',
            'display_name': 'str',
            'description': 'str',
            'glossary_key': 'str',
            'parent_term_key': 'str',
            'is_allowed_to_have_child_terms': 'bool',
            'path': 'str',
            'lifecycle_state': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'created_by_id': 'str',
            'updated_by_id': 'str',
            'owner': 'str',
            'workflow_status': 'str',
            'uri': 'str',
            'associated_object_count': 'int',
            'associated_objects': 'list[TermAssociatedObject]',
            'custom_property_members': 'list[CustomPropertyGetUsage]'
        }

        self.attribute_map = {
            'key': 'key',
            'display_name': 'displayName',
            'description': 'description',
            'glossary_key': 'glossaryKey',
            'parent_term_key': 'parentTermKey',
            'is_allowed_to_have_child_terms': 'isAllowedToHaveChildTerms',
            'path': 'path',
            'lifecycle_state': 'lifecycleState',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'created_by_id': 'createdById',
            'updated_by_id': 'updatedById',
            'owner': 'owner',
            'workflow_status': 'workflowStatus',
            'uri': 'uri',
            'associated_object_count': 'associatedObjectCount',
            'associated_objects': 'associatedObjects',
            'custom_property_members': 'customPropertyMembers'
        }

        self._key = None
        self._display_name = None
        self._description = None
        self._glossary_key = None
        self._parent_term_key = None
        self._is_allowed_to_have_child_terms = None
        self._path = None
        self._lifecycle_state = None
        self._time_created = None
        self._time_updated = None
        self._created_by_id = None
        self._updated_by_id = None
        self._owner = None
        self._workflow_status = None
        self._uri = None
        self._associated_object_count = None
        self._associated_objects = None
        self._custom_property_members = None

    @property
    def key(self):
        """
        **[Required]** Gets the key of this Term.
        Unique term key that is immutable.


        :return: The key of this Term.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this Term.
        Unique term key that is immutable.


        :param key: The key of this Term.
        :type: str
        """
        self._key = key

    @property
    def display_name(self):
        """
        Gets the display_name of this Term.
        A user-friendly display name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :return: The display_name of this Term.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this Term.
        A user-friendly display name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :param display_name: The display_name of this Term.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        Gets the description of this Term.
        Detailed description of the term.


        :return: The description of this Term.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this Term.
        Detailed description of the term.


        :param description: The description of this Term.
        :type: str
        """
        self._description = description

    @property
    def glossary_key(self):
        """
        Gets the glossary_key of this Term.
        Unique id of the parent glossary.


        :return: The glossary_key of this Term.
        :rtype: str
        """
        return self._glossary_key

    @glossary_key.setter
    def glossary_key(self, glossary_key):
        """
        Sets the glossary_key of this Term.
        Unique id of the parent glossary.


        :param glossary_key: The glossary_key of this Term.
        :type: str
        """
        self._glossary_key = glossary_key

    @property
    def parent_term_key(self):
        """
        Gets the parent_term_key of this Term.
        This terms parent term key. Will be null if the term has no parent term.


        :return: The parent_term_key of this Term.
        :rtype: str
        """
        return self._parent_term_key

    @parent_term_key.setter
    def parent_term_key(self, parent_term_key):
        """
        Sets the parent_term_key of this Term.
        This terms parent term key. Will be null if the term has no parent term.


        :param parent_term_key: The parent_term_key of this Term.
        :type: str
        """
        self._parent_term_key = parent_term_key

    @property
    def is_allowed_to_have_child_terms(self):
        """
        Gets the is_allowed_to_have_child_terms of this Term.
        Indicates whether a term may contain child terms.


        :return: The is_allowed_to_have_child_terms of this Term.
        :rtype: bool
        """
        return self._is_allowed_to_have_child_terms

    @is_allowed_to_have_child_terms.setter
    def is_allowed_to_have_child_terms(self, is_allowed_to_have_child_terms):
        """
        Sets the is_allowed_to_have_child_terms of this Term.
        Indicates whether a term may contain child terms.


        :param is_allowed_to_have_child_terms: The is_allowed_to_have_child_terms of this Term.
        :type: bool
        """
        self._is_allowed_to_have_child_terms = is_allowed_to_have_child_terms

    @property
    def path(self):
        """
        Gets the path of this Term.
        Absolute path of the term.


        :return: The path of this Term.
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """
        Sets the path of this Term.
        Absolute path of the term.


        :param path: The path of this Term.
        :type: str
        """
        self._path = path

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this Term.
        The current state of the term.

        Allowed values for this property are: "CREATING", "ACTIVE", "INACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED", "MOVING", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this Term.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this Term.
        The current state of the term.


        :param lifecycle_state: The lifecycle_state of this Term.
        :type: str
        """
        allowed_values = ["CREATING", "ACTIVE", "INACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED", "MOVING"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def time_created(self):
        """
        Gets the time_created of this Term.
        The date and time the term was created, in the format defined by `RFC3339`__.
        Example: `2019-03-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this Term.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this Term.
        The date and time the term was created, in the format defined by `RFC3339`__.
        Example: `2019-03-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this Term.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        Gets the time_updated of this Term.
        The last time that any change was made to the term. An `RFC3339`__ formatted datetime string.

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_updated of this Term.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this Term.
        The last time that any change was made to the term. An `RFC3339`__ formatted datetime string.

        __ https://tools.ietf.org/html/rfc3339


        :param time_updated: The time_updated of this Term.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def created_by_id(self):
        """
        Gets the created_by_id of this Term.
        OCID of the user who created the term.


        :return: The created_by_id of this Term.
        :rtype: str
        """
        return self._created_by_id

    @created_by_id.setter
    def created_by_id(self, created_by_id):
        """
        Sets the created_by_id of this Term.
        OCID of the user who created the term.


        :param created_by_id: The created_by_id of this Term.
        :type: str
        """
        self._created_by_id = created_by_id

    @property
    def updated_by_id(self):
        """
        Gets the updated_by_id of this Term.
        OCID of the user who modified the term.


        :return: The updated_by_id of this Term.
        :rtype: str
        """
        return self._updated_by_id

    @updated_by_id.setter
    def updated_by_id(self, updated_by_id):
        """
        Sets the updated_by_id of this Term.
        OCID of the user who modified the term.


        :param updated_by_id: The updated_by_id of this Term.
        :type: str
        """
        self._updated_by_id = updated_by_id

    @property
    def owner(self):
        """
        Gets the owner of this Term.
        OCID of the user who is the owner of this business terminology.


        :return: The owner of this Term.
        :rtype: str
        """
        return self._owner

    @owner.setter
    def owner(self, owner):
        """
        Sets the owner of this Term.
        OCID of the user who is the owner of this business terminology.


        :param owner: The owner of this Term.
        :type: str
        """
        self._owner = owner

    @property
    def workflow_status(self):
        """
        Gets the workflow_status of this Term.
        Status of the approval process workflow for this business term in the glossary.

        Allowed values for this property are: "NEW", "APPROVED", "UNDER_REVIEW", "ESCALATED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The workflow_status of this Term.
        :rtype: str
        """
        return self._workflow_status

    @workflow_status.setter
    def workflow_status(self, workflow_status):
        """
        Sets the workflow_status of this Term.
        Status of the approval process workflow for this business term in the glossary.


        :param workflow_status: The workflow_status of this Term.
        :type: str
        """
        allowed_values = ["NEW", "APPROVED", "UNDER_REVIEW", "ESCALATED"]
        if not value_allowed_none_or_none_sentinel(workflow_status, allowed_values):
            workflow_status = 'UNKNOWN_ENUM_VALUE'
        self._workflow_status = workflow_status

    @property
    def uri(self):
        """
        Gets the uri of this Term.
        URI to the term instance in the API.


        :return: The uri of this Term.
        :rtype: str
        """
        return self._uri

    @uri.setter
    def uri(self, uri):
        """
        Sets the uri of this Term.
        URI to the term instance in the API.


        :param uri: The uri of this Term.
        :type: str
        """
        self._uri = uri

    @property
    def associated_object_count(self):
        """
        Gets the associated_object_count of this Term.
        The number of objects tagged with this term


        :return: The associated_object_count of this Term.
        :rtype: int
        """
        return self._associated_object_count

    @associated_object_count.setter
    def associated_object_count(self, associated_object_count):
        """
        Sets the associated_object_count of this Term.
        The number of objects tagged with this term


        :param associated_object_count: The associated_object_count of this Term.
        :type: int
        """
        self._associated_object_count = associated_object_count

    @property
    def associated_objects(self):
        """
        Gets the associated_objects of this Term.
        Array of objects associated to a term.


        :return: The associated_objects of this Term.
        :rtype: list[oci.data_catalog.models.TermAssociatedObject]
        """
        return self._associated_objects

    @associated_objects.setter
    def associated_objects(self, associated_objects):
        """
        Sets the associated_objects of this Term.
        Array of objects associated to a term.


        :param associated_objects: The associated_objects of this Term.
        :type: list[oci.data_catalog.models.TermAssociatedObject]
        """
        self._associated_objects = associated_objects

    @property
    def custom_property_members(self):
        """
        Gets the custom_property_members of this Term.
        The list of customized properties along with the values for this object


        :return: The custom_property_members of this Term.
        :rtype: list[oci.data_catalog.models.CustomPropertyGetUsage]
        """
        return self._custom_property_members

    @custom_property_members.setter
    def custom_property_members(self, custom_property_members):
        """
        Sets the custom_property_members of this Term.
        The list of customized properties along with the values for this object


        :param custom_property_members: The custom_property_members of this Term.
        :type: list[oci.data_catalog.models.CustomPropertyGetUsage]
        """
        self._custom_property_members = custom_property_members

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .abstract_frequency_details import AbstractFrequencyDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class MonthlyFrequencyDetails(AbstractFrequencyDetails):
    """
    Frequency Details model for monthly frequency.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new MonthlyFrequencyDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.data_integration.models.MonthlyFrequencyDetails.model_type` attribute
        of this class is ``MONTHLY`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_type:
            The value to assign to the model_type property of this MonthlyFrequencyDetails.
            Allowed values for this property are: "HOURLY", "DAILY", "MONTHLY"
        :type model_type: str

        :param frequency:
            The value to assign to the frequency property of this MonthlyFrequencyDetails.
            Allowed values for this property are: "HOURLY", "DAILY", "MONTHLY"
        :type frequency: str

        :param interval:
            The value to assign to the interval property of this MonthlyFrequencyDetails.
        :type interval: int

        :param time:
            The value to assign to the time property of this MonthlyFrequencyDetails.
        :type time: oci.data_integration.models.Time

        :param days:
            The value to assign to the days property of this MonthlyFrequencyDetails.
        :type days: list[int]

        """
        self.swagger_types = {
            'model_type': 'str',
            'frequency': 'str',
            'interval': 'int',
            'time': 'Time',
            'days': 'list[int]'
        }

        self.attribute_map = {
            'model_type': 'modelType',
            'frequency': 'frequency',
            'interval': 'interval',
            'time': 'time',
            'days': 'days'
        }

        self._model_type = None
        self._frequency = None
        self._interval = None
        self._time = None
        self._days = None
        self._model_type = 'MONTHLY'

    @property
    def interval(self):
        """
        Gets the interval of this MonthlyFrequencyDetails.
        This hold the repeatability aspect of a schedule. i.e. in a monhtly frequency, a task can be scheduled for every month, once in two months, once in tree months etc.


        :return: The interval of this MonthlyFrequencyDetails.
        :rtype: int
        """
        return self._interval

    @interval.setter
    def interval(self, interval):
        """
        Sets the interval of this MonthlyFrequencyDetails.
        This hold the repeatability aspect of a schedule. i.e. in a monhtly frequency, a task can be scheduled for every month, once in two months, once in tree months etc.


        :param interval: The interval of this MonthlyFrequencyDetails.
        :type: int
        """
        self._interval = interval

    @property
    def time(self):
        """
        Gets the time of this MonthlyFrequencyDetails.

        :return: The time of this MonthlyFrequencyDetails.
        :rtype: oci.data_integration.models.Time
        """
        return self._time

    @time.setter
    def time(self, time):
        """
        Sets the time of this MonthlyFrequencyDetails.

        :param time: The time of this MonthlyFrequencyDetails.
        :type: oci.data_integration.models.Time
        """
        self._time = time

    @property
    def days(self):
        """
        Gets the days of this MonthlyFrequencyDetails.
        A list of days of the month to be scheduled. i.e. excute every 2nd,3rd, 10th of the month.


        :return: The days of this MonthlyFrequencyDetails.
        :rtype: list[int]
        """
        return self._days

    @days.setter
    def days(self, days):
        """
        Sets the days of this MonthlyFrequencyDetails.
        A list of days of the month to be scheduled. i.e. excute every 2nd,3rd, 10th of the month.


        :param days: The days of this MonthlyFrequencyDetails.
        :type: list[int]
        """
        self._days = days

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DetectAnomaliesDetails(object):
    """
    Base class for the DetectAnomalies call. It contains the identifier that will
    be used for deciding what type of request this is.
    """

    #: A constant which can be used with the request_type property of a DetectAnomaliesDetails.
    #: This constant has a value of "INLINE"
    REQUEST_TYPE_INLINE = "INLINE"

    #: A constant which can be used with the request_type property of a DetectAnomaliesDetails.
    #: This constant has a value of "BASE64_ENCODED"
    REQUEST_TYPE_BASE64_ENCODED = "BASE64_ENCODED"

    def __init__(self, **kwargs):
        """
        Initializes a new DetectAnomaliesDetails object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.ai_anomaly_detection.models.InlineDetectAnomaliesRequest`
        * :class:`~oci.ai_anomaly_detection.models.EmbeddedDetectAnomaliesRequest`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_id:
            The value to assign to the model_id property of this DetectAnomaliesDetails.
        :type model_id: str

        :param request_type:
            The value to assign to the request_type property of this DetectAnomaliesDetails.
            Allowed values for this property are: "INLINE", "BASE64_ENCODED"
        :type request_type: str

        """
        self.swagger_types = {
            'model_id': 'str',
            'request_type': 'str'
        }

        self.attribute_map = {
            'model_id': 'modelId',
            'request_type': 'requestType'
        }

        self._model_id = None
        self._request_type = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['requestType']

        if type == 'INLINE':
            return 'InlineDetectAnomaliesRequest'

        if type == 'BASE64_ENCODED':
            return 'EmbeddedDetectAnomaliesRequest'
        else:
            return 'DetectAnomaliesDetails'

    @property
    def model_id(self):
        """
        **[Required]** Gets the model_id of this DetectAnomaliesDetails.
        The OCID of the trained model\u3002


        :return: The model_id of this DetectAnomaliesDetails.
        :rtype: str
        """
        return self._model_id

    @model_id.setter
    def model_id(self, model_id):
        """
        Sets the model_id of this DetectAnomaliesDetails.
        The OCID of the trained model\u3002


        :param model_id: The model_id of this DetectAnomaliesDetails.
        :type: str
        """
        self._model_id = model_id

    @property
    def request_type(self):
        """
        **[Required]** Gets the request_type of this DetectAnomaliesDetails.
        Type of request. This parameter will be filled autmatically by classes generated
        by the SDK. For raw curl request, user will have to provide this field.

        Allowed values for this property are: "INLINE", "BASE64_ENCODED"


        :return: The request_type of this DetectAnomaliesDetails.
        :rtype: str
        """
        return self._request_type

    @request_type.setter
    def request_type(self, request_type):
        """
        Sets the request_type of this DetectAnomaliesDetails.
        Type of request. This parameter will be filled autmatically by classes generated
        by the SDK. For raw curl request, user will have to provide this field.


        :param request_type: The request_type of this DetectAnomaliesDetails.
        :type: str
        """
        allowed_values = ["INLINE", "BASE64_ENCODED"]
        if not value_allowed_none_or_none_sentinel(request_type, allowed_values):
            raise ValueError(
                "Invalid value for `request_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._request_type = request_type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ManagedDatabase(object):
    """
    The details of a Managed Database.
    """

    #: A constant which can be used with the database_type property of a ManagedDatabase.
    #: This constant has a value of "EXTERNAL_SIDB"
    DATABASE_TYPE_EXTERNAL_SIDB = "EXTERNAL_SIDB"

    #: A constant which can be used with the database_type property of a ManagedDatabase.
    #: This constant has a value of "EXTERNAL_RAC"
    DATABASE_TYPE_EXTERNAL_RAC = "EXTERNAL_RAC"

    #: A constant which can be used with the database_type property of a ManagedDatabase.
    #: This constant has a value of "CLOUD_SIDB"
    DATABASE_TYPE_CLOUD_SIDB = "CLOUD_SIDB"

    #: A constant which can be used with the database_type property of a ManagedDatabase.
    #: This constant has a value of "CLOUD_RAC"
    DATABASE_TYPE_CLOUD_RAC = "CLOUD_RAC"

    #: A constant which can be used with the database_sub_type property of a ManagedDatabase.
    #: This constant has a value of "CDB"
    DATABASE_SUB_TYPE_CDB = "CDB"

    #: A constant which can be used with the database_sub_type property of a ManagedDatabase.
    #: This constant has a value of "PDB"
    DATABASE_SUB_TYPE_PDB = "PDB"

    #: A constant which can be used with the database_sub_type property of a ManagedDatabase.
    #: This constant has a value of "NON_CDB"
    DATABASE_SUB_TYPE_NON_CDB = "NON_CDB"

    #: A constant which can be used with the deployment_type property of a ManagedDatabase.
    #: This constant has a value of "ONPREMISE"
    DEPLOYMENT_TYPE_ONPREMISE = "ONPREMISE"

    #: A constant which can be used with the deployment_type property of a ManagedDatabase.
    #: This constant has a value of "BM"
    DEPLOYMENT_TYPE_BM = "BM"

    #: A constant which can be used with the deployment_type property of a ManagedDatabase.
    #: This constant has a value of "VM"
    DEPLOYMENT_TYPE_VM = "VM"

    #: A constant which can be used with the deployment_type property of a ManagedDatabase.
    #: This constant has a value of "EXADATA"
    DEPLOYMENT_TYPE_EXADATA = "EXADATA"

    #: A constant which can be used with the deployment_type property of a ManagedDatabase.
    #: This constant has a value of "EXADATA_CC"
    DEPLOYMENT_TYPE_EXADATA_CC = "EXADATA_CC"

    #: A constant which can be used with the management_option property of a ManagedDatabase.
    #: This constant has a value of "BASIC"
    MANAGEMENT_OPTION_BASIC = "BASIC"

    #: A constant which can be used with the management_option property of a ManagedDatabase.
    #: This constant has a value of "ADVANCED"
    MANAGEMENT_OPTION_ADVANCED = "ADVANCED"

    #: A constant which can be used with the database_status property of a ManagedDatabase.
    #: This constant has a value of "UP"
    DATABASE_STATUS_UP = "UP"

    #: A constant which can be used with the database_status property of a ManagedDatabase.
    #: This constant has a value of "DOWN"
    DATABASE_STATUS_DOWN = "DOWN"

    #: A constant which can be used with the database_status property of a ManagedDatabase.
    #: This constant has a value of "UNKNOWN"
    DATABASE_STATUS_UNKNOWN = "UNKNOWN"

    def __init__(self, **kwargs):
        """
        Initializes a new ManagedDatabase object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this ManagedDatabase.
        :type id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this ManagedDatabase.
        :type compartment_id: str

        :param name:
            The value to assign to the name property of this ManagedDatabase.
        :type name: str

        :param database_type:
            The value to assign to the database_type property of this ManagedDatabase.
            Allowed values for this property are: "EXTERNAL_SIDB", "EXTERNAL_RAC", "CLOUD_SIDB", "CLOUD_RAC", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type database_type: str

        :param database_sub_type:
            The value to assign to the database_sub_type property of this ManagedDatabase.
            Allowed values for this property are: "CDB", "PDB", "NON_CDB", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type database_sub_type: str

        :param deployment_type:
            The value to assign to the deployment_type property of this ManagedDatabase.
            Allowed values for this property are: "ONPREMISE", "BM", "VM", "EXADATA", "EXADATA_CC", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type deployment_type: str

        :param management_option:
            The value to assign to the management_option property of this ManagedDatabase.
            Allowed values for this property are: "BASIC", "ADVANCED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type management_option: str

        :param is_cluster:
            The value to assign to the is_cluster property of this ManagedDatabase.
        :type is_cluster: bool

        :param parent_container_id:
            The value to assign to the parent_container_id property of this ManagedDatabase.
        :type parent_container_id: str

        :param managed_database_groups:
            The value to assign to the managed_database_groups property of this ManagedDatabase.
        :type managed_database_groups: list[oci.database_management.models.ParentGroup]

        :param time_created:
            The value to assign to the time_created property of this ManagedDatabase.
        :type time_created: datetime

        :param database_status:
            The value to assign to the database_status property of this ManagedDatabase.
            Allowed values for this property are: "UP", "DOWN", "UNKNOWN", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type database_status: str

        :param parent_container_name:
            The value to assign to the parent_container_name property of this ManagedDatabase.
        :type parent_container_name: str

        :param parent_container_compartment_id:
            The value to assign to the parent_container_compartment_id property of this ManagedDatabase.
        :type parent_container_compartment_id: str

        :param instance_count:
            The value to assign to the instance_count property of this ManagedDatabase.
        :type instance_count: int

        :param instance_details:
            The value to assign to the instance_details property of this ManagedDatabase.
        :type instance_details: list[oci.database_management.models.InstanceDetails]

        :param pdb_count:
            The value to assign to the pdb_count property of this ManagedDatabase.
        :type pdb_count: int

        :param pdb_status:
            The value to assign to the pdb_status property of this ManagedDatabase.
        :type pdb_status: list[oci.database_management.models.PdbStatusDetails]

        :param additional_details:
            The value to assign to the additional_details property of this ManagedDatabase.
        :type additional_details: dict(str, str)

        """
        self.swagger_types = {
            'id': 'str',
            'compartment_id': 'str',
            'name': 'str',
            'database_type': 'str',
            'database_sub_type': 'str',
            'deployment_type': 'str',
            'management_option': 'str',
            'is_cluster': 'bool',
            'parent_container_id': 'str',
            'managed_database_groups': 'list[ParentGroup]',
            'time_created': 'datetime',
            'database_status': 'str',
            'parent_container_name': 'str',
            'parent_container_compartment_id': 'str',
            'instance_count': 'int',
            'instance_details': 'list[InstanceDetails]',
            'pdb_count': 'int',
            'pdb_status': 'list[PdbStatusDetails]',
            'additional_details': 'dict(str, str)'
        }

        self.attribute_map = {
            'id': 'id',
            'compartment_id': 'compartmentId',
            'name': 'name',
            'database_type': 'databaseType',
            'database_sub_type': 'databaseSubType',
            'deployment_type': 'deploymentType',
            'management_option': 'managementOption',
            'is_cluster': 'isCluster',
            'parent_container_id': 'parentContainerId',
            'managed_database_groups': 'managedDatabaseGroups',
            'time_created': 'timeCreated',
            'database_status': 'databaseStatus',
            'parent_container_name': 'parentContainerName',
            'parent_container_compartment_id': 'parentContainerCompartmentId',
            'instance_count': 'instanceCount',
            'instance_details': 'instanceDetails',
            'pdb_count': 'pdbCount',
            'pdb_status': 'pdbStatus',
            'additional_details': 'additionalDetails'
        }

        self._id = None
        self._compartment_id = None
        self._name = None
        self._database_type = None
        self._database_sub_type = None
        self._deployment_type = None
        self._management_option = None
        self._is_cluster = None
        self._parent_container_id = None
        self._managed_database_groups = None
        self._time_created = None
        self._database_status = None
        self._parent_container_name = None
        self._parent_container_compartment_id = None
        self._instance_count = None
        self._instance_details = None
        self._pdb_count = None
        self._pdb_status = None
        self._additional_details = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this ManagedDatabase.
        The `OCID`__ of the Managed Database.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The id of this ManagedDatabase.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ManagedDatabase.
        The `OCID`__ of the Managed Database.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param id: The id of this ManagedDatabase.
        :type: str
        """
        self._id = id

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this ManagedDatabase.
        The `OCID`__ of the compartment.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this ManagedDatabase.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this ManagedDatabase.
        The `OCID`__ of the compartment.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this ManagedDatabase.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def name(self):
        """
        **[Required]** Gets the name of this ManagedDatabase.
        The name of the Managed Database.


        :return: The name of this ManagedDatabase.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ManagedDatabase.
        The name of the Managed Database.


        :param name: The name of this ManagedDatabase.
        :type: str
        """
        self._name = name

    @property
    def database_type(self):
        """
        **[Required]** Gets the database_type of this ManagedDatabase.
        The type of Oracle Database installation.

        Allowed values for this property are: "EXTERNAL_SIDB", "EXTERNAL_RAC", "CLOUD_SIDB", "CLOUD_RAC", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The database_type of this ManagedDatabase.
        :rtype: str
        """
        return self._database_type

    @database_type.setter
    def database_type(self, database_type):
        """
        Sets the database_type of this ManagedDatabase.
        The type of Oracle Database installation.


        :param database_type: The database_type of this ManagedDatabase.
        :type: str
        """
        allowed_values = ["EXTERNAL_SIDB", "EXTERNAL_RAC", "CLOUD_SIDB", "CLOUD_RAC"]
        if not value_allowed_none_or_none_sentinel(database_type, allowed_values):
            database_type = 'UNKNOWN_ENUM_VALUE'
        self._database_type = database_type

    @property
    def database_sub_type(self):
        """
        **[Required]** Gets the database_sub_type of this ManagedDatabase.
        The subtype of the Oracle Database. Indicates whether the database is a Container Database, Pluggable Database, or a Non-container Database.

        Allowed values for this property are: "CDB", "PDB", "NON_CDB", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The database_sub_type of this ManagedDatabase.
        :rtype: str
        """
        return self._database_sub_type

    @database_sub_type.setter
    def database_sub_type(self, database_sub_type):
        """
        Sets the database_sub_type of this ManagedDatabase.
        The subtype of the Oracle Database. Indicates whether the database is a Container Database, Pluggable Database, or a Non-container Database.


        :param database_sub_type: The database_sub_type of this ManagedDatabase.
        :type: str
        """
        allowed_values = ["CDB", "PDB", "NON_CDB"]
        if not value_allowed_none_or_none_sentinel(database_sub_type, allowed_values):
            database_sub_type = 'UNKNOWN_ENUM_VALUE'
        self._database_sub_type = database_sub_type

    @property
    def deployment_type(self):
        """
        Gets the deployment_type of this ManagedDatabase.
        The infrastructure used to deploy the Oracle Database.

        Allowed values for this property are: "ONPREMISE", "BM", "VM", "EXADATA", "EXADATA_CC", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The deployment_type of this ManagedDatabase.
        :rtype: str
        """
        return self._deployment_type

    @deployment_type.setter
    def deployment_type(self, deployment_type):
        """
        Sets the deployment_type of this ManagedDatabase.
        The infrastructure used to deploy the Oracle Database.


        :param deployment_type: The deployment_type of this ManagedDatabase.
        :type: str
        """
        allowed_values = ["ONPREMISE", "BM", "VM", "EXADATA", "EXADATA_CC"]
        if not value_allowed_none_or_none_sentinel(deployment_type, allowed_values):
            deployment_type = 'UNKNOWN_ENUM_VALUE'
        self._deployment_type = deployment_type

    @property
    def management_option(self):
        """
        Gets the management_option of this ManagedDatabase.
        The management option used when enabling Database Management.

        Allowed values for this property are: "BASIC", "ADVANCED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The management_option of this ManagedDatabase.
        :rtype: str
        """
        return self._management_option

    @management_option.setter
    def management_option(self, management_option):
        """
        Sets the management_option of this ManagedDatabase.
        The management option used when enabling Database Management.


        :param management_option: The management_option of this ManagedDatabase.
        :type: str
        """
        allowed_values = ["BASIC", "ADVANCED"]
        if not value_allowed_none_or_none_sentinel(management_option, allowed_values):
            management_option = 'UNKNOWN_ENUM_VALUE'
        self._management_option = management_option

    @property
    def is_cluster(self):
        """
        **[Required]** Gets the is_cluster of this ManagedDatabase.
        Indicates whether the Oracle Database is part of a cluster.


        :return: The is_cluster of this ManagedDatabase.
        :rtype: bool
        """
        return self._is_cluster

    @is_cluster.setter
    def is_cluster(self, is_cluster):
        """
        Sets the is_cluster of this ManagedDatabase.
        Indicates whether the Oracle Database is part of a cluster.


        :param is_cluster: The is_cluster of this ManagedDatabase.
        :type: bool
        """
        self._is_cluster = is_cluster

    @property
    def parent_container_id(self):
        """
        Gets the parent_container_id of this ManagedDatabase.
        The `OCID`__ of the parent Container Database
        if Managed Database is a Pluggable Database.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The parent_container_id of this ManagedDatabase.
        :rtype: str
        """
        return self._parent_container_id

    @parent_container_id.setter
    def parent_container_id(self, parent_container_id):
        """
        Sets the parent_container_id of this ManagedDatabase.
        The `OCID`__ of the parent Container Database
        if Managed Database is a Pluggable Database.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param parent_container_id: The parent_container_id of this ManagedDatabase.
        :type: str
        """
        self._parent_container_id = parent_container_id

    @property
    def managed_database_groups(self):
        """
        Gets the managed_database_groups of this ManagedDatabase.
        A list of Managed Database Groups that the Managed Database belongs to.


        :return: The managed_database_groups of this ManagedDatabase.
        :rtype: list[oci.database_management.models.ParentGroup]
        """
        return self._managed_database_groups

    @managed_database_groups.setter
    def managed_database_groups(self, managed_database_groups):
        """
        Sets the managed_database_groups of this ManagedDatabase.
        A list of Managed Database Groups that the Managed Database belongs to.


        :param managed_database_groups: The managed_database_groups of this ManagedDatabase.
        :type: list[oci.database_management.models.ParentGroup]
        """
        self._managed_database_groups = managed_database_groups

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this ManagedDatabase.
        The date and time the Managed Database was created.


        :return: The time_created of this ManagedDatabase.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this ManagedDatabase.
        The date and time the Managed Database was created.


        :param time_created: The time_created of this ManagedDatabase.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def database_status(self):
        """
        Gets the database_status of this ManagedDatabase.
        The status of the Oracle Database. Indicates whether the status of the database
        is UP, DOWN, or UNKNOWN at the current time.

        Allowed values for this property are: "UP", "DOWN", "UNKNOWN", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The database_status of this ManagedDatabase.
        :rtype: str
        """
        return self._database_status

    @database_status.setter
    def database_status(self, database_status):
        """
        Sets the database_status of this ManagedDatabase.
        The status of the Oracle Database. Indicates whether the status of the database
        is UP, DOWN, or UNKNOWN at the current time.


        :param database_status: The database_status of this ManagedDatabase.
        :type: str
        """
        allowed_values = ["UP", "DOWN", "UNKNOWN"]
        if not value_allowed_none_or_none_sentinel(database_status, allowed_values):
            database_status = 'UNKNOWN_ENUM_VALUE'
        self._database_status = database_status

    @property
    def parent_container_name(self):
        """
        Gets the parent_container_name of this ManagedDatabase.
        The name of the parent Container Database.


        :return: The parent_container_name of this ManagedDatabase.
        :rtype: str
        """
        return self._parent_container_name

    @parent_container_name.setter
    def parent_container_name(self, parent_container_name):
        """
        Sets the parent_container_name of this ManagedDatabase.
        The name of the parent Container Database.


        :param parent_container_name: The parent_container_name of this ManagedDatabase.
        :type: str
        """
        self._parent_container_name = parent_container_name

    @property
    def parent_container_compartment_id(self):
        """
        Gets the parent_container_compartment_id of this ManagedDatabase.
        The `OCID`__ of the compartment
        in which the parent Container Database resides, if the Managed Database
        is a Pluggable Database (PDB).

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The parent_container_compartment_id of this ManagedDatabase.
        :rtype: str
        """
        return self._parent_container_compartment_id

    @parent_container_compartment_id.setter
    def parent_container_compartment_id(self, parent_container_compartment_id):
        """
        Sets the parent_container_compartment_id of this ManagedDatabase.
        The `OCID`__ of the compartment
        in which the parent Container Database resides, if the Managed Database
        is a Pluggable Database (PDB).

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param parent_container_compartment_id: The parent_container_compartment_id of this ManagedDatabase.
        :type: str
        """
        self._parent_container_compartment_id = parent_container_compartment_id

    @property
    def instance_count(self):
        """
        Gets the instance_count of this ManagedDatabase.
        The number of Oracle Real Application Clusters (Oracle RAC) database instances.


        :return: The instance_count of this ManagedDatabase.
        :rtype: int
        """
        return self._instance_count

    @instance_count.setter
    def instance_count(self, instance_count):
        """
        Sets the instance_count of this ManagedDatabase.
        The number of Oracle Real Application Clusters (Oracle RAC) database instances.


        :param instance_count: The instance_count of this ManagedDatabase.
        :type: int
        """
        self._instance_count = instance_count

    @property
    def instance_details(self):
        """
        Gets the instance_details of this ManagedDatabase.
        The details of the Oracle Real Application Clusters (Oracle RAC) database instances.


        :return: The instance_details of this ManagedDatabase.
        :rtype: list[oci.database_management.models.InstanceDetails]
        """
        return self._instance_details

    @instance_details.setter
    def instance_details(self, instance_details):
        """
        Sets the instance_details of this ManagedDatabase.
        The details of the Oracle Real Application Clusters (Oracle RAC) database instances.


        :param instance_details: The instance_details of this ManagedDatabase.
        :type: list[oci.database_management.models.InstanceDetails]
        """
        self._instance_details = instance_details

    @property
    def pdb_count(self):
        """
        Gets the pdb_count of this ManagedDatabase.
        The number of PDBs in the Container Database.


        :return: The pdb_count of this ManagedDatabase.
        :rtype: int
        """
        return self._pdb_count

    @pdb_count.setter
    def pdb_count(self, pdb_count):
        """
        Sets the pdb_count of this ManagedDatabase.
        The number of PDBs in the Container Database.


        :param pdb_count: The pdb_count of this ManagedDatabase.
        :type: int
        """
        self._pdb_count = pdb_count

    @property
    def pdb_status(self):
        """
        Gets the pdb_status of this ManagedDatabase.
        The status of the PDB in the Container Database.


        :return: The pdb_status of this ManagedDatabase.
        :rtype: list[oci.database_management.models.PdbStatusDetails]
        """
        return self._pdb_status

    @pdb_status.setter
    def pdb_status(self, pdb_status):
        """
        Sets the pdb_status of this ManagedDatabase.
        The status of the PDB in the Container Database.


        :param pdb_status: The pdb_status of this ManagedDatabase.
        :type: list[oci.database_management.models.PdbStatusDetails]
        """
        self._pdb_status = pdb_status

    @property
    def additional_details(self):
        """
        Gets the additional_details of this ManagedDatabase.
        The additional details specific to a type of database defined in `{\"key\": \"value\"}` format.
        Example: `{\"bar-key\": \"value\"}`


        :return: The additional_details of this ManagedDatabase.
        :rtype: dict(str, str)
        """
        return self._additional_details

    @additional_details.setter
    def additional_details(self, additional_details):
        """
        Sets the additional_details of this ManagedDatabase.
        The additional details specific to a type of database defined in `{\"key\": \"value\"}` format.
        Example: `{\"bar-key\": \"value\"}`


        :param additional_details: The additional_details of this ManagedDatabase.
        :type: dict(str, str)
        """
        self._additional_details = additional_details

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
